# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class ListLivyComputeSessionsResponseBody(DaraModel):
    def __init__(
        self,
        request_id: str = None,
        sessions: List[main_models.ListLivyComputeSessionsResponseBodySessions] = None,
        total_count: int = None,
    ):
        self.request_id = request_id
        self.sessions = sessions
        self.total_count = total_count

    def validate(self):
        if self.sessions:
            for v1 in self.sessions:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.request_id is not None:
            result['requestId'] = self.request_id

        result['sessions'] = []
        if self.sessions is not None:
            for k1 in self.sessions:
                result['sessions'].append(k1.to_map() if k1 else None)

        if self.total_count is not None:
            result['totalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        self.sessions = []
        if m.get('sessions') is not None:
            for k1 in m.get('sessions'):
                temp_model = main_models.ListLivyComputeSessionsResponseBodySessions()
                self.sessions.append(temp_model.from_map(k1))

        if m.get('totalCount') is not None:
            self.total_count = m.get('totalCount')

        return self

class ListLivyComputeSessionsResponseBodySessions(DaraModel):
    def __init__(
        self,
        compute_id: str = None,
        create_time: int = None,
        cu_hours: float = None,
        end_time: int = None,
        info: str = None,
        mb_seconds: int = None,
        name: str = None,
        queue: str = None,
        session_id: str = None,
        spark_conf: str = None,
        state: str = None,
        vcore_seconds: int = None,
        web_ui: str = None,
    ):
        self.compute_id = compute_id
        self.create_time = create_time
        self.cu_hours = cu_hours
        self.end_time = end_time
        self.info = info
        self.mb_seconds = mb_seconds
        self.name = name
        self.queue = queue
        self.session_id = session_id
        self.spark_conf = spark_conf
        self.state = state
        self.vcore_seconds = vcore_seconds
        self.web_ui = web_ui

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.compute_id is not None:
            result['computeId'] = self.compute_id

        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.cu_hours is not None:
            result['cuHours'] = self.cu_hours

        if self.end_time is not None:
            result['endTime'] = self.end_time

        if self.info is not None:
            result['info'] = self.info

        if self.mb_seconds is not None:
            result['mbSeconds'] = self.mb_seconds

        if self.name is not None:
            result['name'] = self.name

        if self.queue is not None:
            result['queue'] = self.queue

        if self.session_id is not None:
            result['sessionId'] = self.session_id

        if self.spark_conf is not None:
            result['sparkConf'] = self.spark_conf

        if self.state is not None:
            result['state'] = self.state

        if self.vcore_seconds is not None:
            result['vcoreSeconds'] = self.vcore_seconds

        if self.web_ui is not None:
            result['webUI'] = self.web_ui

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('computeId') is not None:
            self.compute_id = m.get('computeId')

        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('cuHours') is not None:
            self.cu_hours = m.get('cuHours')

        if m.get('endTime') is not None:
            self.end_time = m.get('endTime')

        if m.get('info') is not None:
            self.info = m.get('info')

        if m.get('mbSeconds') is not None:
            self.mb_seconds = m.get('mbSeconds')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('queue') is not None:
            self.queue = m.get('queue')

        if m.get('sessionId') is not None:
            self.session_id = m.get('sessionId')

        if m.get('sparkConf') is not None:
            self.spark_conf = m.get('sparkConf')

        if m.get('state') is not None:
            self.state = m.get('state')

        if m.get('vcoreSeconds') is not None:
            self.vcore_seconds = m.get('vcoreSeconds')

        if m.get('webUI') is not None:
            self.web_ui = m.get('webUI')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class TaskInstance(DaraModel):
    def __init__(
        self,
        biz_id: str = None,
        creator: int = None,
        fenix_run_id: str = None,
        gmt_created: str = None,
        task_biz_id: str = None,
        task_info: main_models.Task = None,
        task_status: str = None,
        workspace_biz_id: str = None,
    ):
        # The ID of the folder.
        self.biz_id = biz_id
        # The ID of the user who creates the job.
        self.creator = creator
        # The job run ID.
        self.fenix_run_id = fenix_run_id
        # The time when the job was created.
        self.gmt_created = gmt_created
        # The ID of the data development job.
        self.task_biz_id = task_biz_id
        # The details of the job.
        self.task_info = task_info
        # The job run ID.
        self.task_status = task_status
        # The workspace ID.
        self.workspace_biz_id = workspace_biz_id

    def validate(self):
        if self.task_info:
            self.task_info.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.biz_id is not None:
            result['bizId'] = self.biz_id

        if self.creator is not None:
            result['creator'] = self.creator

        if self.fenix_run_id is not None:
            result['fenixRunId'] = self.fenix_run_id

        if self.gmt_created is not None:
            result['gmtCreated'] = self.gmt_created

        if self.task_biz_id is not None:
            result['taskBizId'] = self.task_biz_id

        if self.task_info is not None:
            result['taskInfo'] = self.task_info.to_map()

        if self.task_status is not None:
            result['taskStatus'] = self.task_status

        if self.workspace_biz_id is not None:
            result['workspaceBizId'] = self.workspace_biz_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('bizId') is not None:
            self.biz_id = m.get('bizId')

        if m.get('creator') is not None:
            self.creator = m.get('creator')

        if m.get('fenixRunId') is not None:
            self.fenix_run_id = m.get('fenixRunId')

        if m.get('gmtCreated') is not None:
            self.gmt_created = m.get('gmtCreated')

        if m.get('taskBizId') is not None:
            self.task_biz_id = m.get('taskBizId')

        if m.get('taskInfo') is not None:
            temp_model = main_models.Task()
            self.task_info = temp_model.from_map(m.get('taskInfo'))

        if m.get('taskStatus') is not None:
            self.task_status = m.get('taskStatus')

        if m.get('workspaceBizId') is not None:
            self.workspace_biz_id = m.get('workspaceBizId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class ListMembersResponseBody(DaraModel):
    def __init__(
        self,
        max_results: int = None,
        members: List[main_models.ListMembersResponseBodyMembers] = None,
        next_token: str = None,
        request_id: str = None,
        total_count: int = None,
    ):
        # 一次获取的最大记录数。
        self.max_results = max_results
        self.members = members
        # 下一页TOKEN。
        self.next_token = next_token
        # 请求ID。
        self.request_id = request_id
        # 记录总数。
        self.total_count = total_count

    def validate(self):
        if self.members:
            for v1 in self.members:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.max_results is not None:
            result['maxResults'] = self.max_results

        result['members'] = []
        if self.members is not None:
            for k1 in self.members:
                result['members'].append(k1.to_map() if k1 else None)

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.total_count is not None:
            result['totalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        self.members = []
        if m.get('members') is not None:
            for k1 in m.get('members'):
                temp_model = main_models.ListMembersResponseBodyMembers()
                self.members.append(temp_model.from_map(k1))

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('totalCount') is not None:
            self.total_count = m.get('totalCount')

        return self

class ListMembersResponseBodyMembers(DaraModel):
    def __init__(
        self,
        actions: List[main_models.ListMembersResponseBodyMembersActions] = None,
        create_time: str = None,
        display_name: str = None,
        member_arn: str = None,
        roles: List[main_models.ListMembersResponseBodyMembersRoles] = None,
        user_name: str = None,
        user_type: str = None,
        visible: bool = None,
    ):
        # 针对此用户允许的操作列表。
        self.actions = actions
        self.create_time = create_time
        # 用户展示名称。
        self.display_name = display_name
        # 用户 arn。
        self.member_arn = member_arn
        # 用户角色列表。
        self.roles = roles
        # 用户名称。
        self.user_name = user_name
        # 用户类型。
        self.user_type = user_type
        self.visible = visible

    def validate(self):
        if self.actions:
            for v1 in self.actions:
                 if v1:
                    v1.validate()
        if self.roles:
            for v1 in self.roles:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['actions'] = []
        if self.actions is not None:
            for k1 in self.actions:
                result['actions'].append(k1.to_map() if k1 else None)

        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.display_name is not None:
            result['displayName'] = self.display_name

        if self.member_arn is not None:
            result['memberArn'] = self.member_arn

        result['roles'] = []
        if self.roles is not None:
            for k1 in self.roles:
                result['roles'].append(k1.to_map() if k1 else None)

        if self.user_name is not None:
            result['userName'] = self.user_name

        if self.user_type is not None:
            result['userType'] = self.user_type

        if self.visible is not None:
            result['visible'] = self.visible

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.actions = []
        if m.get('actions') is not None:
            for k1 in m.get('actions'):
                temp_model = main_models.ListMembersResponseBodyMembersActions()
                self.actions.append(temp_model.from_map(k1))

        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('displayName') is not None:
            self.display_name = m.get('displayName')

        if m.get('memberArn') is not None:
            self.member_arn = m.get('memberArn')

        self.roles = []
        if m.get('roles') is not None:
            for k1 in m.get('roles'):
                temp_model = main_models.ListMembersResponseBodyMembersRoles()
                self.roles.append(temp_model.from_map(k1))

        if m.get('userName') is not None:
            self.user_name = m.get('userName')

        if m.get('userType') is not None:
            self.user_type = m.get('userType')

        if m.get('visible') is not None:
            self.visible = m.get('visible')

        return self

class ListMembersResponseBodyMembersRoles(DaraModel):
    def __init__(
        self,
        actions: List[main_models.ListMembersResponseBodyMembersRolesActions] = None,
        create_time: int = None,
        description: str = None,
        role_arn: str = None,
        role_name: str = None,
    ):
        # 权限列表。
        self.actions = actions
        # 创建时间。
        self.create_time = create_time
        # 描述。
        self.description = description
        # 角色 arn。
        self.role_arn = role_arn
        # 角色名称。
        self.role_name = role_name

    def validate(self):
        if self.actions:
            for v1 in self.actions:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['actions'] = []
        if self.actions is not None:
            for k1 in self.actions:
                result['actions'].append(k1.to_map() if k1 else None)

        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.description is not None:
            result['description'] = self.description

        if self.role_arn is not None:
            result['roleArn'] = self.role_arn

        if self.role_name is not None:
            result['roleName'] = self.role_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.actions = []
        if m.get('actions') is not None:
            for k1 in m.get('actions'):
                temp_model = main_models.ListMembersResponseBodyMembersRolesActions()
                self.actions.append(temp_model.from_map(k1))

        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('roleArn') is not None:
            self.role_arn = m.get('roleArn')

        if m.get('roleName') is not None:
            self.role_name = m.get('roleName')

        return self

class ListMembersResponseBodyMembersRolesActions(DaraModel):
    def __init__(
        self,
        action_arn: str = None,
        action_name: str = None,
        dependencies: List[str] = None,
        description: str = None,
        display_name: str = None,
    ):
        # 行为 arn。
        self.action_arn = action_arn
        # 权限名称。
        self.action_name = action_name
        # action 依赖列表。
        self.dependencies = dependencies
        # action 描述。
        self.description = description
        # 权限展示名称。
        self.display_name = display_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.action_arn is not None:
            result['actionArn'] = self.action_arn

        if self.action_name is not None:
            result['actionName'] = self.action_name

        if self.dependencies is not None:
            result['dependencies'] = self.dependencies

        if self.description is not None:
            result['description'] = self.description

        if self.display_name is not None:
            result['displayName'] = self.display_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('actionArn') is not None:
            self.action_arn = m.get('actionArn')

        if m.get('actionName') is not None:
            self.action_name = m.get('actionName')

        if m.get('dependencies') is not None:
            self.dependencies = m.get('dependencies')

        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('displayName') is not None:
            self.display_name = m.get('displayName')

        return self

class ListMembersResponseBodyMembersActions(DaraModel):
    def __init__(
        self,
        action_arn: str = None,
        action_name: str = None,
        dependencies: List[str] = None,
        description: str = None,
        display_name: str = None,
    ):
        # 行为 arn。
        self.action_arn = action_arn
        # 权限名称。
        self.action_name = action_name
        # action 依赖列表。
        self.dependencies = dependencies
        # action 描述。
        self.description = description
        # 权限展示名称。
        self.display_name = display_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.action_arn is not None:
            result['actionArn'] = self.action_arn

        if self.action_name is not None:
            result['actionName'] = self.action_name

        if self.dependencies is not None:
            result['dependencies'] = self.dependencies

        if self.description is not None:
            result['description'] = self.description

        if self.display_name is not None:
            result['displayName'] = self.display_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('actionArn') is not None:
            self.action_arn = m.get('actionArn')

        if m.get('actionName') is not None:
            self.action_name = m.get('actionName')

        if m.get('dependencies') is not None:
            self.dependencies = m.get('dependencies')

        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('displayName') is not None:
            self.display_name = m.get('displayName')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class CreateWorkspaceRequest(DaraModel):
    def __init__(
        self,
        auto_renew: str = None,
        auto_renew_period: str = None,
        auto_renew_period_unit: str = None,
        auto_start_session_cluster: bool = None,
        client_token: str = None,
        dlf_catalog_id: str = None,
        dlf_type: str = None,
        duration: str = None,
        gpu_spec: List[str] = None,
        oss_bucket: str = None,
        payment_duration_unit: str = None,
        payment_type: str = None,
        ram_role_name: str = None,
        release_type: str = None,
        resource_group_id: str = None,
        resource_spec: main_models.CreateWorkspaceRequestResourceSpec = None,
        tag: List[main_models.CreateWorkspaceRequestTag] = None,
        workspace_name: str = None,
        region_id: str = None,
    ):
        # Specifies whether to enable auto-renewal. This parameter is required only if the paymentType parameter is set to Pre.
        self.auto_renew = auto_renew
        # The auto-renewal duration. This parameter is required only if the paymentType parameter is set to Pre.
        self.auto_renew_period = auto_renew_period
        # The unit of the auto-renewal duration. This parameter is required only if the paymentType parameter is set to Pre.
        self.auto_renew_period_unit = auto_renew_period_unit
        # Specifies whether to automatically start a session.
        self.auto_start_session_cluster = auto_start_session_cluster
        # The client token that is used to ensure the idempotence of the request.
        self.client_token = client_token
        # The information of the Data Lake Formation (DLF) catalog.
        self.dlf_catalog_id = dlf_catalog_id
        # The version of DLF.
        self.dlf_type = dlf_type
        # The subscription period. This parameter is required only if the paymentType parameter is set to Pre.
        self.duration = duration
        self.gpu_spec = gpu_spec
        # The name of the Object Storage Service (OSS) bucket.
        self.oss_bucket = oss_bucket
        # The unit of the subscription duration.
        self.payment_duration_unit = payment_duration_unit
        # The billing method. Valid values:
        # 
        # *   PayAsYouGo
        # *   Pre
        self.payment_type = payment_type
        # The name of the role used to run Spark jobs.
        self.ram_role_name = ram_role_name
        # The type of the version.
        self.release_type = release_type
        self.resource_group_id = resource_group_id
        # The resource specifications.
        self.resource_spec = resource_spec
        self.tag = tag
        # The name of the workspace.
        self.workspace_name = workspace_name
        # The region ID.
        self.region_id = region_id

    def validate(self):
        if self.resource_spec:
            self.resource_spec.validate()
        if self.tag:
            for v1 in self.tag:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_renew is not None:
            result['autoRenew'] = self.auto_renew

        if self.auto_renew_period is not None:
            result['autoRenewPeriod'] = self.auto_renew_period

        if self.auto_renew_period_unit is not None:
            result['autoRenewPeriodUnit'] = self.auto_renew_period_unit

        if self.auto_start_session_cluster is not None:
            result['autoStartSessionCluster'] = self.auto_start_session_cluster

        if self.client_token is not None:
            result['clientToken'] = self.client_token

        if self.dlf_catalog_id is not None:
            result['dlfCatalogId'] = self.dlf_catalog_id

        if self.dlf_type is not None:
            result['dlfType'] = self.dlf_type

        if self.duration is not None:
            result['duration'] = self.duration

        if self.gpu_spec is not None:
            result['gpuSpec'] = self.gpu_spec

        if self.oss_bucket is not None:
            result['ossBucket'] = self.oss_bucket

        if self.payment_duration_unit is not None:
            result['paymentDurationUnit'] = self.payment_duration_unit

        if self.payment_type is not None:
            result['paymentType'] = self.payment_type

        if self.ram_role_name is not None:
            result['ramRoleName'] = self.ram_role_name

        if self.release_type is not None:
            result['releaseType'] = self.release_type

        if self.resource_group_id is not None:
            result['resourceGroupId'] = self.resource_group_id

        if self.resource_spec is not None:
            result['resourceSpec'] = self.resource_spec.to_map()

        result['tag'] = []
        if self.tag is not None:
            for k1 in self.tag:
                result['tag'].append(k1.to_map() if k1 else None)

        if self.workspace_name is not None:
            result['workspaceName'] = self.workspace_name

        if self.region_id is not None:
            result['regionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('autoRenew') is not None:
            self.auto_renew = m.get('autoRenew')

        if m.get('autoRenewPeriod') is not None:
            self.auto_renew_period = m.get('autoRenewPeriod')

        if m.get('autoRenewPeriodUnit') is not None:
            self.auto_renew_period_unit = m.get('autoRenewPeriodUnit')

        if m.get('autoStartSessionCluster') is not None:
            self.auto_start_session_cluster = m.get('autoStartSessionCluster')

        if m.get('clientToken') is not None:
            self.client_token = m.get('clientToken')

        if m.get('dlfCatalogId') is not None:
            self.dlf_catalog_id = m.get('dlfCatalogId')

        if m.get('dlfType') is not None:
            self.dlf_type = m.get('dlfType')

        if m.get('duration') is not None:
            self.duration = m.get('duration')

        if m.get('gpuSpec') is not None:
            self.gpu_spec = m.get('gpuSpec')

        if m.get('ossBucket') is not None:
            self.oss_bucket = m.get('ossBucket')

        if m.get('paymentDurationUnit') is not None:
            self.payment_duration_unit = m.get('paymentDurationUnit')

        if m.get('paymentType') is not None:
            self.payment_type = m.get('paymentType')

        if m.get('ramRoleName') is not None:
            self.ram_role_name = m.get('ramRoleName')

        if m.get('releaseType') is not None:
            self.release_type = m.get('releaseType')

        if m.get('resourceGroupId') is not None:
            self.resource_group_id = m.get('resourceGroupId')

        if m.get('resourceSpec') is not None:
            temp_model = main_models.CreateWorkspaceRequestResourceSpec()
            self.resource_spec = temp_model.from_map(m.get('resourceSpec'))

        self.tag = []
        if m.get('tag') is not None:
            for k1 in m.get('tag'):
                temp_model = main_models.CreateWorkspaceRequestTag()
                self.tag.append(temp_model.from_map(k1))

        if m.get('workspaceName') is not None:
            self.workspace_name = m.get('workspaceName')

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        return self

class CreateWorkspaceRequestTag(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        self.key = key
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['key'] = self.key

        if self.value is not None:
            result['value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('key') is not None:
            self.key = m.get('key')

        if m.get('value') is not None:
            self.value = m.get('value')

        return self

class CreateWorkspaceRequestResourceSpec(DaraModel):
    def __init__(
        self,
        cu: str = None,
        gpu: int = None,
    ):
        # The maximum resource quota for a workspace.
        self.cu = cu
        self.gpu = gpu

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cu is not None:
            result['cu'] = self.cu

        if self.gpu is not None:
            result['gpu'] = self.gpu

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cu') is not None:
            self.cu = m.get('cu')

        if m.get('gpu') is not None:
            self.gpu = m.get('gpu')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListSqlStatementContentsRequest(DaraModel):
    def __init__(
        self,
        file_name: str = None,
        max_results: int = None,
        next_token: str = None,
    ):
        self.file_name = file_name
        self.max_results = max_results
        self.next_token = next_token

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.file_name is not None:
            result['fileName'] = self.file_name

        if self.max_results is not None:
            result['maxResults'] = self.max_results

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('fileName') is not None:
            self.file_name = m.get('fileName')

        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class CreateKyuubiTokenRequest(DaraModel):
    def __init__(
        self,
        auto_expire_configuration: main_models.CreateKyuubiTokenRequestAutoExpireConfiguration = None,
        member_arns: List[str] = None,
        name: str = None,
        token: str = None,
        region_id: str = None,
    ):
        self.auto_expire_configuration = auto_expire_configuration
        self.member_arns = member_arns
        self.name = name
        self.token = token
        self.region_id = region_id

    def validate(self):
        if self.auto_expire_configuration:
            self.auto_expire_configuration.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_expire_configuration is not None:
            result['autoExpireConfiguration'] = self.auto_expire_configuration.to_map()

        if self.member_arns is not None:
            result['memberArns'] = self.member_arns

        if self.name is not None:
            result['name'] = self.name

        if self.token is not None:
            result['token'] = self.token

        if self.region_id is not None:
            result['regionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('autoExpireConfiguration') is not None:
            temp_model = main_models.CreateKyuubiTokenRequestAutoExpireConfiguration()
            self.auto_expire_configuration = temp_model.from_map(m.get('autoExpireConfiguration'))

        if m.get('memberArns') is not None:
            self.member_arns = m.get('memberArns')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('token') is not None:
            self.token = m.get('token')

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        return self

class CreateKyuubiTokenRequestAutoExpireConfiguration(DaraModel):
    def __init__(
        self,
        enable: bool = None,
        expire_days: int = None,
    ):
        self.enable = enable
        self.expire_days = expire_days

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.enable is not None:
            result['enable'] = self.enable

        if self.expire_days is not None:
            result['expireDays'] = self.expire_days

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('enable') is not None:
            self.enable = m.get('enable')

        if m.get('expireDays') is not None:
            self.expire_days = m.get('expireDays')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class ListRayClusterResponseBody(DaraModel):
    def __init__(
        self,
        ray_clusters: List[main_models.ListRayClusterResponseBodyRayClusters] = None,
        request_id: str = None,
    ):
        self.ray_clusters = ray_clusters
        self.request_id = request_id

    def validate(self):
        if self.ray_clusters:
            for v1 in self.ray_clusters:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['rayClusters'] = []
        if self.ray_clusters is not None:
            for k1 in self.ray_clusters:
                result['rayClusters'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['requestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.ray_clusters = []
        if m.get('rayClusters') is not None:
            for k1 in m.get('rayClusters'):
                temp_model = main_models.ListRayClusterResponseBodyRayClusters()
                self.ray_clusters.append(temp_model.from_map(k1))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        return self

class ListRayClusterResponseBodyRayClusters(DaraModel):
    def __init__(
        self,
        cluster_id: str = None,
        create_time: int = None,
        creator: str = None,
        creator_name: str = None,
        dashboard_url: str = None,
        description: str = None,
        display_release_version: str = None,
        grpc_endpoint: str = None,
        head_spec: main_models.ListRayClusterResponseBodyRayClustersHeadSpec = None,
        instance_id: str = None,
        message: str = None,
        modified: bool = None,
        modified_time: int = None,
        modifier: str = None,
        modifier_name: str = None,
        name: str = None,
        network_service_name: str = None,
        start_time: int = None,
        state: str = None,
        user_id: str = None,
        worker_spec: List[main_models.ListRayClusterResponseBodyRayClustersWorkerSpec] = None,
    ):
        self.cluster_id = cluster_id
        self.create_time = create_time
        self.creator = creator
        self.creator_name = creator_name
        self.dashboard_url = dashboard_url
        self.description = description
        self.display_release_version = display_release_version
        self.grpc_endpoint = grpc_endpoint
        self.head_spec = head_spec
        self.instance_id = instance_id
        self.message = message
        self.modified = modified
        self.modified_time = modified_time
        self.modifier = modifier
        self.modifier_name = modifier_name
        self.name = name
        self.network_service_name = network_service_name
        self.start_time = start_time
        self.state = state
        self.user_id = user_id
        self.worker_spec = worker_spec

    def validate(self):
        if self.head_spec:
            self.head_spec.validate()
        if self.worker_spec:
            for v1 in self.worker_spec:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cluster_id is not None:
            result['clusterId'] = self.cluster_id

        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.creator is not None:
            result['creator'] = self.creator

        if self.creator_name is not None:
            result['creatorName'] = self.creator_name

        if self.dashboard_url is not None:
            result['dashboardUrl'] = self.dashboard_url

        if self.description is not None:
            result['description'] = self.description

        if self.display_release_version is not None:
            result['displayReleaseVersion'] = self.display_release_version

        if self.grpc_endpoint is not None:
            result['grpcEndpoint'] = self.grpc_endpoint

        if self.head_spec is not None:
            result['headSpec'] = self.head_spec.to_map()

        if self.instance_id is not None:
            result['instanceId'] = self.instance_id

        if self.message is not None:
            result['message'] = self.message

        if self.modified is not None:
            result['modified'] = self.modified

        if self.modified_time is not None:
            result['modifiedTime'] = self.modified_time

        if self.modifier is not None:
            result['modifier'] = self.modifier

        if self.modifier_name is not None:
            result['modifierName'] = self.modifier_name

        if self.name is not None:
            result['name'] = self.name

        if self.network_service_name is not None:
            result['networkServiceName'] = self.network_service_name

        if self.start_time is not None:
            result['startTime'] = self.start_time

        if self.state is not None:
            result['state'] = self.state

        if self.user_id is not None:
            result['userId'] = self.user_id

        result['workerSpec'] = []
        if self.worker_spec is not None:
            for k1 in self.worker_spec:
                result['workerSpec'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('clusterId') is not None:
            self.cluster_id = m.get('clusterId')

        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('creator') is not None:
            self.creator = m.get('creator')

        if m.get('creatorName') is not None:
            self.creator_name = m.get('creatorName')

        if m.get('dashboardUrl') is not None:
            self.dashboard_url = m.get('dashboardUrl')

        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('displayReleaseVersion') is not None:
            self.display_release_version = m.get('displayReleaseVersion')

        if m.get('grpcEndpoint') is not None:
            self.grpc_endpoint = m.get('grpcEndpoint')

        if m.get('headSpec') is not None:
            temp_model = main_models.ListRayClusterResponseBodyRayClustersHeadSpec()
            self.head_spec = temp_model.from_map(m.get('headSpec'))

        if m.get('instanceId') is not None:
            self.instance_id = m.get('instanceId')

        if m.get('message') is not None:
            self.message = m.get('message')

        if m.get('modified') is not None:
            self.modified = m.get('modified')

        if m.get('modifiedTime') is not None:
            self.modified_time = m.get('modifiedTime')

        if m.get('modifier') is not None:
            self.modifier = m.get('modifier')

        if m.get('modifierName') is not None:
            self.modifier_name = m.get('modifierName')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('networkServiceName') is not None:
            self.network_service_name = m.get('networkServiceName')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        if m.get('state') is not None:
            self.state = m.get('state')

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        self.worker_spec = []
        if m.get('workerSpec') is not None:
            for k1 in m.get('workerSpec'):
                temp_model = main_models.ListRayClusterResponseBodyRayClustersWorkerSpec()
                self.worker_spec.append(temp_model.from_map(k1))

        return self

class ListRayClusterResponseBodyRayClustersWorkerSpec(DaraModel):
    def __init__(
        self,
        cpu: str = None,
        gpu_spec: str = None,
        group_name: str = None,
        max_replica: int = None,
        memory: str = None,
        min_replica: int = None,
        queue_name: str = None,
        replica: int = None,
        worker_type: str = None,
    ):
        self.cpu = cpu
        self.gpu_spec = gpu_spec
        self.group_name = group_name
        self.max_replica = max_replica
        self.memory = memory
        self.min_replica = min_replica
        self.queue_name = queue_name
        self.replica = replica
        self.worker_type = worker_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cpu is not None:
            result['cpu'] = self.cpu

        if self.gpu_spec is not None:
            result['gpuSpec'] = self.gpu_spec

        if self.group_name is not None:
            result['groupName'] = self.group_name

        if self.max_replica is not None:
            result['maxReplica'] = self.max_replica

        if self.memory is not None:
            result['memory'] = self.memory

        if self.min_replica is not None:
            result['minReplica'] = self.min_replica

        if self.queue_name is not None:
            result['queueName'] = self.queue_name

        if self.replica is not None:
            result['replica'] = self.replica

        if self.worker_type is not None:
            result['workerType'] = self.worker_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cpu') is not None:
            self.cpu = m.get('cpu')

        if m.get('gpuSpec') is not None:
            self.gpu_spec = m.get('gpuSpec')

        if m.get('groupName') is not None:
            self.group_name = m.get('groupName')

        if m.get('maxReplica') is not None:
            self.max_replica = m.get('maxReplica')

        if m.get('memory') is not None:
            self.memory = m.get('memory')

        if m.get('minReplica') is not None:
            self.min_replica = m.get('minReplica')

        if m.get('queueName') is not None:
            self.queue_name = m.get('queueName')

        if m.get('replica') is not None:
            self.replica = m.get('replica')

        if m.get('workerType') is not None:
            self.worker_type = m.get('workerType')

        return self

class ListRayClusterResponseBodyRayClustersHeadSpec(DaraModel):
    def __init__(
        self,
        cpu: str = None,
        enable_auto_scaling: bool = None,
        gpu_spec: str = None,
        idle_timeout_seconds: int = None,
        memory: str = None,
        queue_name: str = None,
        replica: int = None,
    ):
        self.cpu = cpu
        self.enable_auto_scaling = enable_auto_scaling
        self.gpu_spec = gpu_spec
        self.idle_timeout_seconds = idle_timeout_seconds
        self.memory = memory
        self.queue_name = queue_name
        self.replica = replica

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cpu is not None:
            result['cpu'] = self.cpu

        if self.enable_auto_scaling is not None:
            result['enableAutoScaling'] = self.enable_auto_scaling

        if self.gpu_spec is not None:
            result['gpuSpec'] = self.gpu_spec

        if self.idle_timeout_seconds is not None:
            result['idleTimeoutSeconds'] = self.idle_timeout_seconds

        if self.memory is not None:
            result['memory'] = self.memory

        if self.queue_name is not None:
            result['queueName'] = self.queue_name

        if self.replica is not None:
            result['replica'] = self.replica

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cpu') is not None:
            self.cpu = m.get('cpu')

        if m.get('enableAutoScaling') is not None:
            self.enable_auto_scaling = m.get('enableAutoScaling')

        if m.get('gpuSpec') is not None:
            self.gpu_spec = m.get('gpuSpec')

        if m.get('idleTimeoutSeconds') is not None:
            self.idle_timeout_seconds = m.get('idleTimeoutSeconds')

        if m.get('memory') is not None:
            self.memory = m.get('memory')

        if m.get('queueName') is not None:
            self.queue_name = m.get('queueName')

        if m.get('replica') is not None:
            self.replica = m.get('replica')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class GetCuHoursResponseBody(DaraModel):
    def __init__(
        self,
        data: main_models.GetCuHoursResponseBodyData = None,
        request_id: str = None,
    ):
        # The returned data.
        self.data = data
        # The request ID.
        self.request_id = request_id

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['data'] = self.data.to_map()

        if self.request_id is not None:
            result['requestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('data') is not None:
            temp_model = main_models.GetCuHoursResponseBodyData()
            self.data = temp_model.from_map(m.get('data'))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        return self

class GetCuHoursResponseBodyData(DaraModel):
    def __init__(
        self,
        cu_hours: str = None,
    ):
        # The number of CU-hours consumed by a queue during a specified cycle. The value is an estimated value. Refer to your Alibaba Cloud bill for the actual number of consumed CU-hours.
        self.cu_hours = cu_hours

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cu_hours is not None:
            result['cuHours'] = self.cu_hours

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cuHours') is not None:
            self.cu_hours = m.get('cuHours')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class RunLog(DaraModel):
    def __init__(
        self,
        driver_startup: str = None,
        driver_std_error: str = None,
        driver_std_out: str = None,
        driver_syslog: str = None,
    ):
        # The path of the startup file.
        self.driver_startup = driver_startup
        # The path of the stderr file.
        self.driver_std_error = driver_std_error
        # The path of the stdout file.
        self.driver_std_out = driver_std_out
        # The path of the syslog file.
        self.driver_syslog = driver_syslog

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.driver_startup is not None:
            result['driverStartup'] = self.driver_startup

        if self.driver_std_error is not None:
            result['driverStdError'] = self.driver_std_error

        if self.driver_std_out is not None:
            result['driverStdOut'] = self.driver_std_out

        if self.driver_syslog is not None:
            result['driverSyslog'] = self.driver_syslog

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('driverStartup') is not None:
            self.driver_startup = m.get('driverStartup')

        if m.get('driverStdError') is not None:
            self.driver_std_error = m.get('driverStdError')

        if m.get('driverStdOut') is not None:
            self.driver_std_out = m.get('driverStdOut')

        if m.get('driverSyslog') is not None:
            self.driver_syslog = m.get('driverSyslog')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class Tag(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        # The tag key.
        self.key = key
        # The tag value.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['key'] = self.key

        if self.value is not None:
            result['value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('key') is not None:
            self.key = m.get('key')

        if m.get('value') is not None:
            self.value = m.get('value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class GetRayClusterResponseBody(DaraModel):
    def __init__(
        self,
        cluster_id: str = None,
        create_time: int = None,
        creator: str = None,
        creator_name: str = None,
        dashboard_url: str = None,
        description: str = None,
        display_release_version: str = None,
        extra_param: str = None,
        grpc_endpoint: str = None,
        head_spec: main_models.GetRayClusterResponseBodyHeadSpec = None,
        instance_id: str = None,
        instances: List[main_models.GetRayClusterResponseBodyInstances] = None,
        job_url: str = None,
        job_url_inner: str = None,
        message: str = None,
        modified: bool = None,
        modified_time: int = None,
        modifier: str = None,
        modifier_name: str = None,
        name: str = None,
        network_service_name: str = None,
        request_id: str = None,
        start_time: int = None,
        state: str = None,
        submit_token: str = None,
        user_id: str = None,
        volume_ids: List[str] = None,
        worker_spec: List[main_models.GetRayClusterResponseBodyWorkerSpec] = None,
    ):
        self.cluster_id = cluster_id
        self.create_time = create_time
        self.creator = creator
        self.creator_name = creator_name
        self.dashboard_url = dashboard_url
        self.description = description
        self.display_release_version = display_release_version
        self.extra_param = extra_param
        self.grpc_endpoint = grpc_endpoint
        self.head_spec = head_spec
        self.instance_id = instance_id
        self.instances = instances
        self.job_url = job_url
        self.job_url_inner = job_url_inner
        self.message = message
        self.modified = modified
        self.modified_time = modified_time
        self.modifier = modifier
        self.modifier_name = modifier_name
        self.name = name
        self.network_service_name = network_service_name
        self.request_id = request_id
        self.start_time = start_time
        self.state = state
        self.submit_token = submit_token
        self.user_id = user_id
        self.volume_ids = volume_ids
        self.worker_spec = worker_spec

    def validate(self):
        if self.head_spec:
            self.head_spec.validate()
        if self.instances:
            for v1 in self.instances:
                 if v1:
                    v1.validate()
        if self.worker_spec:
            for v1 in self.worker_spec:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cluster_id is not None:
            result['clusterId'] = self.cluster_id

        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.creator is not None:
            result['creator'] = self.creator

        if self.creator_name is not None:
            result['creatorName'] = self.creator_name

        if self.dashboard_url is not None:
            result['dashboardUrl'] = self.dashboard_url

        if self.description is not None:
            result['description'] = self.description

        if self.display_release_version is not None:
            result['displayReleaseVersion'] = self.display_release_version

        if self.extra_param is not None:
            result['extraParam'] = self.extra_param

        if self.grpc_endpoint is not None:
            result['grpcEndpoint'] = self.grpc_endpoint

        if self.head_spec is not None:
            result['headSpec'] = self.head_spec.to_map()

        if self.instance_id is not None:
            result['instanceId'] = self.instance_id

        result['instances'] = []
        if self.instances is not None:
            for k1 in self.instances:
                result['instances'].append(k1.to_map() if k1 else None)

        if self.job_url is not None:
            result['jobUrl'] = self.job_url

        if self.job_url_inner is not None:
            result['jobUrlInner'] = self.job_url_inner

        if self.message is not None:
            result['message'] = self.message

        if self.modified is not None:
            result['modified'] = self.modified

        if self.modified_time is not None:
            result['modifiedTime'] = self.modified_time

        if self.modifier is not None:
            result['modifier'] = self.modifier

        if self.modifier_name is not None:
            result['modifierName'] = self.modifier_name

        if self.name is not None:
            result['name'] = self.name

        if self.network_service_name is not None:
            result['networkServiceName'] = self.network_service_name

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.start_time is not None:
            result['startTime'] = self.start_time

        if self.state is not None:
            result['state'] = self.state

        if self.submit_token is not None:
            result['submitToken'] = self.submit_token

        if self.user_id is not None:
            result['userId'] = self.user_id

        if self.volume_ids is not None:
            result['volumeIds'] = self.volume_ids

        result['workerSpec'] = []
        if self.worker_spec is not None:
            for k1 in self.worker_spec:
                result['workerSpec'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('clusterId') is not None:
            self.cluster_id = m.get('clusterId')

        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('creator') is not None:
            self.creator = m.get('creator')

        if m.get('creatorName') is not None:
            self.creator_name = m.get('creatorName')

        if m.get('dashboardUrl') is not None:
            self.dashboard_url = m.get('dashboardUrl')

        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('displayReleaseVersion') is not None:
            self.display_release_version = m.get('displayReleaseVersion')

        if m.get('extraParam') is not None:
            self.extra_param = m.get('extraParam')

        if m.get('grpcEndpoint') is not None:
            self.grpc_endpoint = m.get('grpcEndpoint')

        if m.get('headSpec') is not None:
            temp_model = main_models.GetRayClusterResponseBodyHeadSpec()
            self.head_spec = temp_model.from_map(m.get('headSpec'))

        if m.get('instanceId') is not None:
            self.instance_id = m.get('instanceId')

        self.instances = []
        if m.get('instances') is not None:
            for k1 in m.get('instances'):
                temp_model = main_models.GetRayClusterResponseBodyInstances()
                self.instances.append(temp_model.from_map(k1))

        if m.get('jobUrl') is not None:
            self.job_url = m.get('jobUrl')

        if m.get('jobUrlInner') is not None:
            self.job_url_inner = m.get('jobUrlInner')

        if m.get('message') is not None:
            self.message = m.get('message')

        if m.get('modified') is not None:
            self.modified = m.get('modified')

        if m.get('modifiedTime') is not None:
            self.modified_time = m.get('modifiedTime')

        if m.get('modifier') is not None:
            self.modifier = m.get('modifier')

        if m.get('modifierName') is not None:
            self.modifier_name = m.get('modifierName')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('networkServiceName') is not None:
            self.network_service_name = m.get('networkServiceName')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        if m.get('state') is not None:
            self.state = m.get('state')

        if m.get('submitToken') is not None:
            self.submit_token = m.get('submitToken')

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        if m.get('volumeIds') is not None:
            self.volume_ids = m.get('volumeIds')

        self.worker_spec = []
        if m.get('workerSpec') is not None:
            for k1 in m.get('workerSpec'):
                temp_model = main_models.GetRayClusterResponseBodyWorkerSpec()
                self.worker_spec.append(temp_model.from_map(k1))

        return self

class GetRayClusterResponseBodyWorkerSpec(DaraModel):
    def __init__(
        self,
        cpu: str = None,
        gpu_spec: str = None,
        group_name: str = None,
        max_replica: int = None,
        memory: str = None,
        min_replica: int = None,
        queue_name: str = None,
        replica: int = None,
        worker_type: str = None,
    ):
        self.cpu = cpu
        self.gpu_spec = gpu_spec
        self.group_name = group_name
        self.max_replica = max_replica
        self.memory = memory
        self.min_replica = min_replica
        self.queue_name = queue_name
        self.replica = replica
        self.worker_type = worker_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cpu is not None:
            result['cpu'] = self.cpu

        if self.gpu_spec is not None:
            result['gpuSpec'] = self.gpu_spec

        if self.group_name is not None:
            result['groupName'] = self.group_name

        if self.max_replica is not None:
            result['maxReplica'] = self.max_replica

        if self.memory is not None:
            result['memory'] = self.memory

        if self.min_replica is not None:
            result['minReplica'] = self.min_replica

        if self.queue_name is not None:
            result['queueName'] = self.queue_name

        if self.replica is not None:
            result['replica'] = self.replica

        if self.worker_type is not None:
            result['workerType'] = self.worker_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cpu') is not None:
            self.cpu = m.get('cpu')

        if m.get('gpuSpec') is not None:
            self.gpu_spec = m.get('gpuSpec')

        if m.get('groupName') is not None:
            self.group_name = m.get('groupName')

        if m.get('maxReplica') is not None:
            self.max_replica = m.get('maxReplica')

        if m.get('memory') is not None:
            self.memory = m.get('memory')

        if m.get('minReplica') is not None:
            self.min_replica = m.get('minReplica')

        if m.get('queueName') is not None:
            self.queue_name = m.get('queueName')

        if m.get('replica') is not None:
            self.replica = m.get('replica')

        if m.get('workerType') is not None:
            self.worker_type = m.get('workerType')

        return self

class GetRayClusterResponseBodyInstances(DaraModel):
    def __init__(
        self,
        container_exit_code: int = None,
        container_state: str = None,
        container_state_message: str = None,
        container_state_reason: str = None,
        create_time: int = None,
        instance_id: str = None,
        message: str = None,
        phase: str = None,
        reason: str = None,
        start_time: int = None,
        type: str = None,
    ):
        self.container_exit_code = container_exit_code
        self.container_state = container_state
        self.container_state_message = container_state_message
        self.container_state_reason = container_state_reason
        self.create_time = create_time
        self.instance_id = instance_id
        self.message = message
        self.phase = phase
        self.reason = reason
        self.start_time = start_time
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.container_exit_code is not None:
            result['containerExitCode'] = self.container_exit_code

        if self.container_state is not None:
            result['containerState'] = self.container_state

        if self.container_state_message is not None:
            result['containerStateMessage'] = self.container_state_message

        if self.container_state_reason is not None:
            result['containerStateReason'] = self.container_state_reason

        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.instance_id is not None:
            result['instanceId'] = self.instance_id

        if self.message is not None:
            result['message'] = self.message

        if self.phase is not None:
            result['phase'] = self.phase

        if self.reason is not None:
            result['reason'] = self.reason

        if self.start_time is not None:
            result['startTime'] = self.start_time

        if self.type is not None:
            result['type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('containerExitCode') is not None:
            self.container_exit_code = m.get('containerExitCode')

        if m.get('containerState') is not None:
            self.container_state = m.get('containerState')

        if m.get('containerStateMessage') is not None:
            self.container_state_message = m.get('containerStateMessage')

        if m.get('containerStateReason') is not None:
            self.container_state_reason = m.get('containerStateReason')

        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('instanceId') is not None:
            self.instance_id = m.get('instanceId')

        if m.get('message') is not None:
            self.message = m.get('message')

        if m.get('phase') is not None:
            self.phase = m.get('phase')

        if m.get('reason') is not None:
            self.reason = m.get('reason')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        if m.get('type') is not None:
            self.type = m.get('type')

        return self

class GetRayClusterResponseBodyHeadSpec(DaraModel):
    def __init__(
        self,
        cpu: str = None,
        enable_auto_scaling: bool = None,
        gpu_spec: str = None,
        idle_timeout_seconds: int = None,
        memory: str = None,
        queue_name: str = None,
        replica: int = None,
    ):
        self.cpu = cpu
        self.enable_auto_scaling = enable_auto_scaling
        self.gpu_spec = gpu_spec
        self.idle_timeout_seconds = idle_timeout_seconds
        self.memory = memory
        self.queue_name = queue_name
        self.replica = replica

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cpu is not None:
            result['cpu'] = self.cpu

        if self.enable_auto_scaling is not None:
            result['enableAutoScaling'] = self.enable_auto_scaling

        if self.gpu_spec is not None:
            result['gpuSpec'] = self.gpu_spec

        if self.idle_timeout_seconds is not None:
            result['idleTimeoutSeconds'] = self.idle_timeout_seconds

        if self.memory is not None:
            result['memory'] = self.memory

        if self.queue_name is not None:
            result['queueName'] = self.queue_name

        if self.replica is not None:
            result['replica'] = self.replica

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cpu') is not None:
            self.cpu = m.get('cpu')

        if m.get('enableAutoScaling') is not None:
            self.enable_auto_scaling = m.get('enableAutoScaling')

        if m.get('gpuSpec') is not None:
            self.gpu_spec = m.get('gpuSpec')

        if m.get('idleTimeoutSeconds') is not None:
            self.idle_timeout_seconds = m.get('idleTimeoutSeconds')

        if m.get('memory') is not None:
            self.memory = m.get('memory')

        if m.get('queueName') is not None:
            self.queue_name = m.get('queueName')

        if m.get('replica') is not None:
            self.replica = m.get('replica')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class ListLogContentsResponseBody(DaraModel):
    def __init__(
        self,
        list_log_content: main_models.ListLogContentsResponseBodyListLogContent = None,
        request_id: str = None,
    ):
        # Log content.
        self.list_log_content = list_log_content
        # The request ID.
        self.request_id = request_id

    def validate(self):
        if self.list_log_content:
            self.list_log_content.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.list_log_content is not None:
            result['listLogContent'] = self.list_log_content.to_map()

        if self.request_id is not None:
            result['requestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('listLogContent') is not None:
            temp_model = main_models.ListLogContentsResponseBodyListLogContent()
            self.list_log_content = temp_model.from_map(m.get('listLogContent'))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        return self

class ListLogContentsResponseBodyListLogContent(DaraModel):
    def __init__(
        self,
        contents: List[main_models.ListLogContentsResponseBodyListLogContentContents] = None,
        total_length: int = None,
    ):
        # List of log line contents.
        self.contents = contents
        # Total number of log lines.
        self.total_length = total_length

    def validate(self):
        if self.contents:
            for v1 in self.contents:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['contents'] = []
        if self.contents is not None:
            for k1 in self.contents:
                result['contents'].append(k1.to_map() if k1 else None)

        if self.total_length is not None:
            result['totalLength'] = self.total_length

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.contents = []
        if m.get('contents') is not None:
            for k1 in m.get('contents'):
                temp_model = main_models.ListLogContentsResponseBodyListLogContentContents()
                self.contents.append(temp_model.from_map(k1))

        if m.get('totalLength') is not None:
            self.total_length = m.get('totalLength')

        return self

class ListLogContentsResponseBodyListLogContentContents(DaraModel):
    def __init__(
        self,
        line_content: str = None,
    ):
        # Log line content.
        self.line_content = line_content

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.line_content is not None:
            result['LineContent'] = self.line_content

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('LineContent') is not None:
            self.line_content = m.get('LineContent')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class Category(DaraModel):
    def __init__(
        self,
        biz_id: str = None,
        creator: int = None,
        gmt_created: str = None,
        gmt_modified: str = None,
        modifier: int = None,
        name: str = None,
        parent_biz_id: str = None,
        type: str = None,
    ):
        # The folder ID.
        # 
        # This parameter is required.
        self.biz_id = biz_id
        # The ID of the user who creates the folder.
        # 
        # This parameter is required.
        self.creator = creator
        # The time when the folder was created.
        # 
        # This parameter is required.
        self.gmt_created = gmt_created
        # The time when the folder was last updated.
        # 
        # This parameter is required.
        self.gmt_modified = gmt_modified
        # The ID of the user who last modifies the folder.
        # 
        # This parameter is required.
        self.modifier = modifier
        # The name of the folder.
        # 
        # This parameter is required.
        self.name = name
        # The parent folder ID.
        self.parent_biz_id = parent_biz_id
        # The type of the folder.
        # 
        # This parameter is required.
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.biz_id is not None:
            result['bizId'] = self.biz_id

        if self.creator is not None:
            result['creator'] = self.creator

        if self.gmt_created is not None:
            result['gmtCreated'] = self.gmt_created

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.modifier is not None:
            result['modifier'] = self.modifier

        if self.name is not None:
            result['name'] = self.name

        if self.parent_biz_id is not None:
            result['parentBizId'] = self.parent_biz_id

        if self.type is not None:
            result['type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('bizId') is not None:
            self.biz_id = m.get('bizId')

        if m.get('creator') is not None:
            self.creator = m.get('creator')

        if m.get('gmtCreated') is not None:
            self.gmt_created = m.get('gmtCreated')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('modifier') is not None:
            self.modifier = m.get('modifier')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('parentBizId') is not None:
            self.parent_biz_id = m.get('parentBizId')

        if m.get('type') is not None:
            self.type = m.get('type')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from ._artifact import Artifact
from ._category import Category
from ._configuration import Configuration
from ._configuration_overrides import ConfigurationOverrides
from ._credential import Credential
from ._job_driver import JobDriver
from ._kerberos_conf import KerberosConf
from ._principal_action import PrincipalAction
from ._release_version_image import ReleaseVersionImage
from ._run_log import RunLog
from ._spark_conf import SparkConf
from ._sql_output import SqlOutput
from ._tag import Tag
from ._task import Task
from ._task_instance import TaskInstance
from ._task_snapshot import TaskSnapshot
from ._template import Template
from ._time_range import TimeRange
from ._add_members_request import AddMembersRequest
from ._add_members_response_body import AddMembersResponseBody
from ._add_members_response import AddMembersResponse
from ._cancel_job_run_request import CancelJobRunRequest
from ._cancel_job_run_response_body import CancelJobRunResponseBody
from ._cancel_job_run_response import CancelJobRunResponse
from ._cancel_kyuubi_spark_application_request import CancelKyuubiSparkApplicationRequest
from ._cancel_kyuubi_spark_application_response_body import CancelKyuubiSparkApplicationResponseBody
from ._cancel_kyuubi_spark_application_response import CancelKyuubiSparkApplicationResponse
from ._create_kyuubi_service_request import CreateKyuubiServiceRequest
from ._create_kyuubi_service_response_body import CreateKyuubiServiceResponseBody
from ._create_kyuubi_service_response import CreateKyuubiServiceResponse
from ._create_kyuubi_token_request import CreateKyuubiTokenRequest
from ._create_kyuubi_token_response_body import CreateKyuubiTokenResponseBody
from ._create_kyuubi_token_response import CreateKyuubiTokenResponse
from ._create_livy_compute_request import CreateLivyComputeRequest
from ._create_livy_compute_response_body import CreateLivyComputeResponseBody
from ._create_livy_compute_response import CreateLivyComputeResponse
from ._create_livy_compute_token_request import CreateLivyComputeTokenRequest
from ._create_livy_compute_token_response_body import CreateLivyComputeTokenResponseBody
from ._create_livy_compute_token_response import CreateLivyComputeTokenResponse
from ._create_process_definition_with_schedule_request import CreateProcessDefinitionWithScheduleRequest
from ._create_process_definition_with_schedule_shrink_request import CreateProcessDefinitionWithScheduleShrinkRequest
from ._create_process_definition_with_schedule_response_body import CreateProcessDefinitionWithScheduleResponseBody
from ._create_process_definition_with_schedule_response import CreateProcessDefinitionWithScheduleResponse
from ._create_ray_cluster_request import CreateRayClusterRequest
from ._create_ray_cluster_response_body import CreateRayClusterResponseBody
from ._create_ray_cluster_response import CreateRayClusterResponse
from ._create_session_cluster_request import CreateSessionClusterRequest
from ._create_session_cluster_response_body import CreateSessionClusterResponseBody
from ._create_session_cluster_response import CreateSessionClusterResponse
from ._create_sql_statement_request import CreateSqlStatementRequest
from ._create_sql_statement_response_body import CreateSqlStatementResponseBody
from ._create_sql_statement_response import CreateSqlStatementResponse
from ._create_workspace_request import CreateWorkspaceRequest
from ._create_workspace_response_body import CreateWorkspaceResponseBody
from ._create_workspace_response import CreateWorkspaceResponse
from ._delete_kyuubi_service_response_body import DeleteKyuubiServiceResponseBody
from ._delete_kyuubi_service_response import DeleteKyuubiServiceResponse
from ._delete_kyuubi_token_request import DeleteKyuubiTokenRequest
from ._delete_kyuubi_token_response_body import DeleteKyuubiTokenResponseBody
from ._delete_kyuubi_token_response import DeleteKyuubiTokenResponse
from ._delete_livy_compute_request import DeleteLivyComputeRequest
from ._delete_livy_compute_response_body import DeleteLivyComputeResponseBody
from ._delete_livy_compute_response import DeleteLivyComputeResponse
from ._delete_livy_compute_token_request import DeleteLivyComputeTokenRequest
from ._delete_livy_compute_token_response_body import DeleteLivyComputeTokenResponseBody
from ._delete_livy_compute_token_response import DeleteLivyComputeTokenResponse
from ._delete_ray_cluster_response_body import DeleteRayClusterResponseBody
from ._delete_ray_cluster_response import DeleteRayClusterResponse
from ._edit_workspace_queue_request import EditWorkspaceQueueRequest
from ._edit_workspace_queue_response_body import EditWorkspaceQueueResponseBody
from ._edit_workspace_queue_response import EditWorkspaceQueueResponse
from ._generate_task_codes_request import GenerateTaskCodesRequest
from ._generate_task_codes_response_body import GenerateTaskCodesResponseBody
from ._generate_task_codes_response import GenerateTaskCodesResponse
from ._get_cu_hours_request import GetCuHoursRequest
from ._get_cu_hours_response_body import GetCuHoursResponseBody
from ._get_cu_hours_response import GetCuHoursResponse
from ._get_doctor_application_request import GetDoctorApplicationRequest
from ._get_doctor_application_response_body import GetDoctorApplicationResponseBody
from ._get_doctor_application_response import GetDoctorApplicationResponse
from ._get_job_run_request import GetJobRunRequest
from ._get_job_run_response_body import GetJobRunResponseBody
from ._get_job_run_response import GetJobRunResponse
from ._get_kyuubi_service_response_body import GetKyuubiServiceResponseBody
from ._get_kyuubi_service_response import GetKyuubiServiceResponse
from ._get_kyuubi_token_request import GetKyuubiTokenRequest
from ._get_kyuubi_token_response_body import GetKyuubiTokenResponseBody
from ._get_kyuubi_token_response import GetKyuubiTokenResponse
from ._get_livy_compute_request import GetLivyComputeRequest
from ._get_livy_compute_response_body import GetLivyComputeResponseBody
from ._get_livy_compute_response import GetLivyComputeResponse
from ._get_livy_compute_token_request import GetLivyComputeTokenRequest
from ._get_livy_compute_token_response_body import GetLivyComputeTokenResponseBody
from ._get_livy_compute_token_response import GetLivyComputeTokenResponse
from ._get_ray_cluster_response_body import GetRayClusterResponseBody
from ._get_ray_cluster_response import GetRayClusterResponse
from ._get_run_configuration_request import GetRunConfigurationRequest
from ._get_run_configuration_response_body import GetRunConfigurationResponseBody
from ._get_run_configuration_response import GetRunConfigurationResponse
from ._get_session_cluster_request import GetSessionClusterRequest
from ._get_session_cluster_response_body import GetSessionClusterResponseBody
from ._get_session_cluster_response import GetSessionClusterResponse
from ._get_sql_statement_request import GetSqlStatementRequest
from ._get_sql_statement_response_body import GetSqlStatementResponseBody
from ._get_sql_statement_response import GetSqlStatementResponse
from ._get_template_request import GetTemplateRequest
from ._get_template_response_body import GetTemplateResponseBody
from ._get_template_response import GetTemplateResponse
from ._grant_role_to_users_request import GrantRoleToUsersRequest
from ._grant_role_to_users_response_body import GrantRoleToUsersResponseBody
from ._grant_role_to_users_response import GrantRoleToUsersResponse
from ._list_catalogs_request import ListCatalogsRequest
from ._list_catalogs_response_body import ListCatalogsResponseBody
from ._list_catalogs_response import ListCatalogsResponse
from ._list_job_executors_request import ListJobExecutorsRequest
from ._list_job_executors_response_body import ListJobExecutorsResponseBody
from ._list_job_executors_response import ListJobExecutorsResponse
from ._list_job_runs_request import ListJobRunsRequest
from ._list_job_runs_shrink_request import ListJobRunsShrinkRequest
from ._list_job_runs_response_body import ListJobRunsResponseBody
from ._list_job_runs_response import ListJobRunsResponse
from ._list_kyuubi_services_response_body import ListKyuubiServicesResponseBody
from ._list_kyuubi_services_response import ListKyuubiServicesResponse
from ._list_kyuubi_spark_applications_request import ListKyuubiSparkApplicationsRequest
from ._list_kyuubi_spark_applications_shrink_request import ListKyuubiSparkApplicationsShrinkRequest
from ._list_kyuubi_spark_applications_response_body import ListKyuubiSparkApplicationsResponseBody
from ._list_kyuubi_spark_applications_response import ListKyuubiSparkApplicationsResponse
from ._list_kyuubi_token_request import ListKyuubiTokenRequest
from ._list_kyuubi_token_response_body import ListKyuubiTokenResponseBody
from ._list_kyuubi_token_response import ListKyuubiTokenResponse
from ._list_livy_compute_request import ListLivyComputeRequest
from ._list_livy_compute_response_body import ListLivyComputeResponseBody
from ._list_livy_compute_response import ListLivyComputeResponse
from ._list_livy_compute_sessions_request import ListLivyComputeSessionsRequest
from ._list_livy_compute_sessions_response_body import ListLivyComputeSessionsResponseBody
from ._list_livy_compute_sessions_response import ListLivyComputeSessionsResponse
from ._list_livy_compute_token_request import ListLivyComputeTokenRequest
from ._list_livy_compute_token_response_body import ListLivyComputeTokenResponseBody
from ._list_livy_compute_token_response import ListLivyComputeTokenResponse
from ._list_log_contents_request import ListLogContentsRequest
from ._list_log_contents_response_body import ListLogContentsResponseBody
from ._list_log_contents_response import ListLogContentsResponse
from ._list_members_request import ListMembersRequest
from ._list_members_response_body import ListMembersResponseBody
from ._list_members_response import ListMembersResponse
from ._list_ray_cluster_request import ListRayClusterRequest
from ._list_ray_cluster_response_body import ListRayClusterResponseBody
from ._list_ray_cluster_response import ListRayClusterResponse
from ._list_release_versions_request import ListReleaseVersionsRequest
from ._list_release_versions_response_body import ListReleaseVersionsResponseBody
from ._list_release_versions_response import ListReleaseVersionsResponse
from ._list_session_clusters_request import ListSessionClustersRequest
from ._list_session_clusters_response_body import ListSessionClustersResponseBody
from ._list_session_clusters_response import ListSessionClustersResponse
from ._list_sql_statement_contents_request import ListSqlStatementContentsRequest
from ._list_sql_statement_contents_response_body import ListSqlStatementContentsResponseBody
from ._list_sql_statement_contents_response import ListSqlStatementContentsResponse
from ._list_template_request import ListTemplateRequest
from ._list_template_response_body import ListTemplateResponseBody
from ._list_template_response import ListTemplateResponse
from ._list_workspace_queues_request import ListWorkspaceQueuesRequest
from ._list_workspace_queues_response_body import ListWorkspaceQueuesResponseBody
from ._list_workspace_queues_response import ListWorkspaceQueuesResponse
from ._list_workspaces_request import ListWorkspacesRequest
from ._list_workspaces_shrink_request import ListWorkspacesShrinkRequest
from ._list_workspaces_response_body import ListWorkspacesResponseBody
from ._list_workspaces_response import ListWorkspacesResponse
from ._refresh_livy_compute_token_request import RefreshLivyComputeTokenRequest
from ._refresh_livy_compute_token_response_body import RefreshLivyComputeTokenResponseBody
from ._refresh_livy_compute_token_response import RefreshLivyComputeTokenResponse
from ._start_job_run_request import StartJobRunRequest
from ._start_job_run_response_body import StartJobRunResponseBody
from ._start_job_run_response import StartJobRunResponse
from ._start_kyuubi_service_response_body import StartKyuubiServiceResponseBody
from ._start_kyuubi_service_response import StartKyuubiServiceResponse
from ._start_livy_compute_request import StartLivyComputeRequest
from ._start_livy_compute_response_body import StartLivyComputeResponseBody
from ._start_livy_compute_response import StartLivyComputeResponse
from ._start_process_instance_request import StartProcessInstanceRequest
from ._start_process_instance_response_body import StartProcessInstanceResponseBody
from ._start_process_instance_response import StartProcessInstanceResponse
from ._start_ray_cluster_request import StartRayClusterRequest
from ._start_ray_cluster_response_body import StartRayClusterResponseBody
from ._start_ray_cluster_response import StartRayClusterResponse
from ._start_session_cluster_request import StartSessionClusterRequest
from ._start_session_cluster_response_body import StartSessionClusterResponseBody
from ._start_session_cluster_response import StartSessionClusterResponse
from ._stop_kyuubi_service_response_body import StopKyuubiServiceResponseBody
from ._stop_kyuubi_service_response import StopKyuubiServiceResponse
from ._stop_livy_compute_request import StopLivyComputeRequest
from ._stop_livy_compute_response_body import StopLivyComputeResponseBody
from ._stop_livy_compute_response import StopLivyComputeResponse
from ._stop_ray_cluster_request import StopRayClusterRequest
from ._stop_ray_cluster_response_body import StopRayClusterResponseBody
from ._stop_ray_cluster_response import StopRayClusterResponse
from ._stop_session_cluster_request import StopSessionClusterRequest
from ._stop_session_cluster_response_body import StopSessionClusterResponseBody
from ._stop_session_cluster_response import StopSessionClusterResponse
from ._terminate_sql_statement_request import TerminateSqlStatementRequest
from ._terminate_sql_statement_response_body import TerminateSqlStatementResponseBody
from ._terminate_sql_statement_response import TerminateSqlStatementResponse
from ._update_kyuubi_service_request import UpdateKyuubiServiceRequest
from ._update_kyuubi_service_response_body import UpdateKyuubiServiceResponseBody
from ._update_kyuubi_service_response import UpdateKyuubiServiceResponse
from ._update_kyuubi_token_request import UpdateKyuubiTokenRequest
from ._update_kyuubi_token_response_body import UpdateKyuubiTokenResponseBody
from ._update_kyuubi_token_response import UpdateKyuubiTokenResponse
from ._update_livy_compute_request import UpdateLivyComputeRequest
from ._update_livy_compute_response_body import UpdateLivyComputeResponseBody
from ._update_livy_compute_response import UpdateLivyComputeResponse
from ._update_process_definition_with_schedule_request import UpdateProcessDefinitionWithScheduleRequest
from ._update_process_definition_with_schedule_shrink_request import UpdateProcessDefinitionWithScheduleShrinkRequest
from ._update_process_definition_with_schedule_response_body import UpdateProcessDefinitionWithScheduleResponseBody
from ._update_process_definition_with_schedule_response import UpdateProcessDefinitionWithScheduleResponse
from ._update_ray_cluster_request import UpdateRayClusterRequest
from ._update_ray_cluster_response_body import UpdateRayClusterResponseBody
from ._update_ray_cluster_response import UpdateRayClusterResponse
from ._configuration_overrides import ConfigurationOverridesConfigurations
from ._job_driver import JobDriverSparkSubmit
from ._sql_output import SqlOutputRows
from ._sql_output import SqlOutputSchemaFields
from ._sql_output import SqlOutputSchema
from ._task import TaskCredential
from ._cancel_kyuubi_spark_application_response_body import CancelKyuubiSparkApplicationResponseBodyBody
from ._create_kyuubi_service_response_body import CreateKyuubiServiceResponseBodyData
from ._create_kyuubi_token_request import CreateKyuubiTokenRequestAutoExpireConfiguration
from ._create_kyuubi_token_response_body import CreateKyuubiTokenResponseBodyData
from ._create_livy_compute_request import CreateLivyComputeRequestAutoStartConfiguration
from ._create_livy_compute_request import CreateLivyComputeRequestAutoStopConfiguration
from ._create_livy_compute_response_body import CreateLivyComputeResponseBodyData
from ._create_livy_compute_token_request import CreateLivyComputeTokenRequestAutoExpireConfiguration
from ._create_livy_compute_token_response_body import CreateLivyComputeTokenResponseBodyData
from ._create_process_definition_with_schedule_request import CreateProcessDefinitionWithScheduleRequestGlobalParams
from ._create_process_definition_with_schedule_request import CreateProcessDefinitionWithScheduleRequestSchedule
from ._create_process_definition_with_schedule_request import CreateProcessDefinitionWithScheduleRequestTaskDefinitionJsonTaskParamsLocalParams
from ._create_process_definition_with_schedule_request import CreateProcessDefinitionWithScheduleRequestTaskDefinitionJsonTaskParamsSparkConf
from ._create_process_definition_with_schedule_request import CreateProcessDefinitionWithScheduleRequestTaskDefinitionJsonTaskParams
from ._create_process_definition_with_schedule_request import CreateProcessDefinitionWithScheduleRequestTaskDefinitionJson
from ._create_process_definition_with_schedule_request import CreateProcessDefinitionWithScheduleRequestTaskRelationJson
from ._create_process_definition_with_schedule_response_body import CreateProcessDefinitionWithScheduleResponseBodyData
from ._create_ray_cluster_request import CreateRayClusterRequestHeadSpec
from ._create_ray_cluster_request import CreateRayClusterRequestWorkerSpec
from ._create_session_cluster_request import CreateSessionClusterRequestApplicationConfigs
from ._create_session_cluster_request import CreateSessionClusterRequestAutoStartConfiguration
from ._create_session_cluster_request import CreateSessionClusterRequestAutoStopConfiguration
from ._create_sql_statement_response_body import CreateSqlStatementResponseBodyData
from ._create_workspace_request import CreateWorkspaceRequestResourceSpec
from ._create_workspace_request import CreateWorkspaceRequestTag
from ._edit_workspace_queue_request import EditWorkspaceQueueRequestResourceSpec
from ._get_cu_hours_response_body import GetCuHoursResponseBodyData
from ._get_doctor_application_response_body import GetDoctorApplicationResponseBodyData
from ._get_job_run_response_body import GetJobRunResponseBodyJobRunConfigurationOverrides
from ._get_job_run_response_body import GetJobRunResponseBodyJobRunStateChangeReason
from ._get_job_run_response_body import GetJobRunResponseBodyJobRun
from ._get_kyuubi_service_response_body import GetKyuubiServiceResponseBodyData
from ._get_kyuubi_token_response_body import GetKyuubiTokenResponseBodyDataAutoExpireConfiguration
from ._get_kyuubi_token_response_body import GetKyuubiTokenResponseBodyData
from ._get_livy_compute_response_body import GetLivyComputeResponseBodyDataAutoStopConfiguration
from ._get_livy_compute_response_body import GetLivyComputeResponseBodyData
from ._get_livy_compute_token_response_body import GetLivyComputeTokenResponseBodyDataAutoExpireConfiguration
from ._get_livy_compute_token_response_body import GetLivyComputeTokenResponseBodyData
from ._get_ray_cluster_response_body import GetRayClusterResponseBodyHeadSpec
from ._get_ray_cluster_response_body import GetRayClusterResponseBodyInstances
from ._get_ray_cluster_response_body import GetRayClusterResponseBodyWorkerSpec
from ._get_run_configuration_response_body import GetRunConfigurationResponseBodyRunConfigurationApplicationConfigs
from ._get_run_configuration_response_body import GetRunConfigurationResponseBodyRunConfigurationLogConfig
from ._get_run_configuration_response_body import GetRunConfigurationResponseBodyRunConfiguration
from ._get_session_cluster_response_body import GetSessionClusterResponseBodySessionClusterApplicationConfigs
from ._get_session_cluster_response_body import GetSessionClusterResponseBodySessionClusterAutoStartConfiguration
from ._get_session_cluster_response_body import GetSessionClusterResponseBodySessionClusterAutoStopConfiguration
from ._get_session_cluster_response_body import GetSessionClusterResponseBodySessionClusterStateChangeReason
from ._get_session_cluster_response_body import GetSessionClusterResponseBodySessionCluster
from ._get_sql_statement_response_body import GetSqlStatementResponseBodyDataSqlOutputs
from ._get_sql_statement_response_body import GetSqlStatementResponseBodyData
from ._list_catalogs_response_body import ListCatalogsResponseBodyCatalogs
from ._list_job_executors_response_body import ListJobExecutorsResponseBodyExexutors
from ._list_job_runs_request import ListJobRunsRequestEndTime
from ._list_job_runs_request import ListJobRunsRequestStartTime
from ._list_job_runs_request import ListJobRunsRequestTags
from ._list_job_runs_response_body import ListJobRunsResponseBodyJobRunsConfigurationOverrides
from ._list_job_runs_response_body import ListJobRunsResponseBodyJobRunsStateChangeReason
from ._list_job_runs_response_body import ListJobRunsResponseBodyJobRuns
from ._list_kyuubi_services_response_body import ListKyuubiServicesResponseBodyDataKyuubiServices
from ._list_kyuubi_services_response_body import ListKyuubiServicesResponseBodyData
from ._list_kyuubi_spark_applications_request import ListKyuubiSparkApplicationsRequestEndTime
from ._list_kyuubi_spark_applications_request import ListKyuubiSparkApplicationsRequestStartTime
from ._list_kyuubi_spark_applications_response_body import ListKyuubiSparkApplicationsResponseBodyApplications
from ._list_kyuubi_token_response_body import ListKyuubiTokenResponseBodyDataTokens
from ._list_kyuubi_token_response_body import ListKyuubiTokenResponseBodyData
from ._list_livy_compute_response_body import ListLivyComputeResponseBodyDataLivyComputes
from ._list_livy_compute_response_body import ListLivyComputeResponseBodyData
from ._list_livy_compute_sessions_response_body import ListLivyComputeSessionsResponseBodySessions
from ._list_livy_compute_token_response_body import ListLivyComputeTokenResponseBodyDataTokens
from ._list_livy_compute_token_response_body import ListLivyComputeTokenResponseBodyData
from ._list_log_contents_response_body import ListLogContentsResponseBodyListLogContentContents
from ._list_log_contents_response_body import ListLogContentsResponseBodyListLogContent
from ._list_members_response_body import ListMembersResponseBodyMembersActions
from ._list_members_response_body import ListMembersResponseBodyMembersRolesActions
from ._list_members_response_body import ListMembersResponseBodyMembersRoles
from ._list_members_response_body import ListMembersResponseBodyMembers
from ._list_ray_cluster_response_body import ListRayClusterResponseBodyRayClustersHeadSpec
from ._list_ray_cluster_response_body import ListRayClusterResponseBodyRayClustersWorkerSpec
from ._list_ray_cluster_response_body import ListRayClusterResponseBodyRayClusters
from ._list_release_versions_response_body import ListReleaseVersionsResponseBodyReleaseVersions
from ._list_session_clusters_response_body import ListSessionClustersResponseBodySessionClustersApplicationConfigs
from ._list_session_clusters_response_body import ListSessionClustersResponseBodySessionClustersAutoStartConfiguration
from ._list_session_clusters_response_body import ListSessionClustersResponseBodySessionClustersAutoStopConfiguration
from ._list_session_clusters_response_body import ListSessionClustersResponseBodySessionClustersStateChangeReason
from ._list_session_clusters_response_body import ListSessionClustersResponseBodySessionClusters
from ._list_sql_statement_contents_response_body import ListSqlStatementContentsResponseBodySqlStatementContents
from ._list_workspace_queues_response_body import ListWorkspaceQueuesResponseBodyQueuesAllowActions
from ._list_workspace_queues_response_body import ListWorkspaceQueuesResponseBodyQueues
from ._list_workspaces_request import ListWorkspacesRequestTag
from ._list_workspaces_response_body import ListWorkspacesResponseBodyWorkspacesPrePaidQuota
from ._list_workspaces_response_body import ListWorkspacesResponseBodyWorkspacesStateChangeReason
from ._list_workspaces_response_body import ListWorkspacesResponseBodyWorkspacesTags
from ._list_workspaces_response_body import ListWorkspacesResponseBodyWorkspaces
from ._refresh_livy_compute_token_request import RefreshLivyComputeTokenRequestAutoExpireConfiguration
from ._start_job_run_request import StartJobRunRequestConfigurationOverridesConfigurations
from ._start_job_run_request import StartJobRunRequestConfigurationOverrides
from ._update_kyuubi_token_request import UpdateKyuubiTokenRequestAutoExpireConfiguration
from ._update_livy_compute_request import UpdateLivyComputeRequestAutoStartConfiguration
from ._update_livy_compute_request import UpdateLivyComputeRequestAutoStopConfiguration
from ._update_process_definition_with_schedule_request import UpdateProcessDefinitionWithScheduleRequestGlobalParams
from ._update_process_definition_with_schedule_request import UpdateProcessDefinitionWithScheduleRequestSchedule
from ._update_process_definition_with_schedule_request import UpdateProcessDefinitionWithScheduleRequestTaskDefinitionJsonTaskParamsLocalParams
from ._update_process_definition_with_schedule_request import UpdateProcessDefinitionWithScheduleRequestTaskDefinitionJsonTaskParamsSparkConf
from ._update_process_definition_with_schedule_request import UpdateProcessDefinitionWithScheduleRequestTaskDefinitionJsonTaskParams
from ._update_process_definition_with_schedule_request import UpdateProcessDefinitionWithScheduleRequestTaskDefinitionJson
from ._update_process_definition_with_schedule_request import UpdateProcessDefinitionWithScheduleRequestTaskRelationJson
from ._update_process_definition_with_schedule_response_body import UpdateProcessDefinitionWithScheduleResponseBodyData
from ._update_ray_cluster_request import UpdateRayClusterRequestHeadSpec
from ._update_ray_cluster_request import UpdateRayClusterRequestWorkerSpec

__all__ = [
    Artifact,
    Category,
    Configuration,
    ConfigurationOverrides,
    Credential,
    JobDriver,
    KerberosConf,
    PrincipalAction,
    ReleaseVersionImage,
    RunLog,
    SparkConf,
    SqlOutput,
    Tag,
    Task,
    TaskInstance,
    TaskSnapshot,
    Template,
    TimeRange,
    AddMembersRequest,
    AddMembersResponseBody,
    AddMembersResponse,
    CancelJobRunRequest,
    CancelJobRunResponseBody,
    CancelJobRunResponse,
    CancelKyuubiSparkApplicationRequest,
    CancelKyuubiSparkApplicationResponseBody,
    CancelKyuubiSparkApplicationResponse,
    CreateKyuubiServiceRequest,
    CreateKyuubiServiceResponseBody,
    CreateKyuubiServiceResponse,
    CreateKyuubiTokenRequest,
    CreateKyuubiTokenResponseBody,
    CreateKyuubiTokenResponse,
    CreateLivyComputeRequest,
    CreateLivyComputeResponseBody,
    CreateLivyComputeResponse,
    CreateLivyComputeTokenRequest,
    CreateLivyComputeTokenResponseBody,
    CreateLivyComputeTokenResponse,
    CreateProcessDefinitionWithScheduleRequest,
    CreateProcessDefinitionWithScheduleShrinkRequest,
    CreateProcessDefinitionWithScheduleResponseBody,
    CreateProcessDefinitionWithScheduleResponse,
    CreateRayClusterRequest,
    CreateRayClusterResponseBody,
    CreateRayClusterResponse,
    CreateSessionClusterRequest,
    CreateSessionClusterResponseBody,
    CreateSessionClusterResponse,
    CreateSqlStatementRequest,
    CreateSqlStatementResponseBody,
    CreateSqlStatementResponse,
    CreateWorkspaceRequest,
    CreateWorkspaceResponseBody,
    CreateWorkspaceResponse,
    DeleteKyuubiServiceResponseBody,
    DeleteKyuubiServiceResponse,
    DeleteKyuubiTokenRequest,
    DeleteKyuubiTokenResponseBody,
    DeleteKyuubiTokenResponse,
    DeleteLivyComputeRequest,
    DeleteLivyComputeResponseBody,
    DeleteLivyComputeResponse,
    DeleteLivyComputeTokenRequest,
    DeleteLivyComputeTokenResponseBody,
    DeleteLivyComputeTokenResponse,
    DeleteRayClusterResponseBody,
    DeleteRayClusterResponse,
    EditWorkspaceQueueRequest,
    EditWorkspaceQueueResponseBody,
    EditWorkspaceQueueResponse,
    GenerateTaskCodesRequest,
    GenerateTaskCodesResponseBody,
    GenerateTaskCodesResponse,
    GetCuHoursRequest,
    GetCuHoursResponseBody,
    GetCuHoursResponse,
    GetDoctorApplicationRequest,
    GetDoctorApplicationResponseBody,
    GetDoctorApplicationResponse,
    GetJobRunRequest,
    GetJobRunResponseBody,
    GetJobRunResponse,
    GetKyuubiServiceResponseBody,
    GetKyuubiServiceResponse,
    GetKyuubiTokenRequest,
    GetKyuubiTokenResponseBody,
    GetKyuubiTokenResponse,
    GetLivyComputeRequest,
    GetLivyComputeResponseBody,
    GetLivyComputeResponse,
    GetLivyComputeTokenRequest,
    GetLivyComputeTokenResponseBody,
    GetLivyComputeTokenResponse,
    GetRayClusterResponseBody,
    GetRayClusterResponse,
    GetRunConfigurationRequest,
    GetRunConfigurationResponseBody,
    GetRunConfigurationResponse,
    GetSessionClusterRequest,
    GetSessionClusterResponseBody,
    GetSessionClusterResponse,
    GetSqlStatementRequest,
    GetSqlStatementResponseBody,
    GetSqlStatementResponse,
    GetTemplateRequest,
    GetTemplateResponseBody,
    GetTemplateResponse,
    GrantRoleToUsersRequest,
    GrantRoleToUsersResponseBody,
    GrantRoleToUsersResponse,
    ListCatalogsRequest,
    ListCatalogsResponseBody,
    ListCatalogsResponse,
    ListJobExecutorsRequest,
    ListJobExecutorsResponseBody,
    ListJobExecutorsResponse,
    ListJobRunsRequest,
    ListJobRunsShrinkRequest,
    ListJobRunsResponseBody,
    ListJobRunsResponse,
    ListKyuubiServicesResponseBody,
    ListKyuubiServicesResponse,
    ListKyuubiSparkApplicationsRequest,
    ListKyuubiSparkApplicationsShrinkRequest,
    ListKyuubiSparkApplicationsResponseBody,
    ListKyuubiSparkApplicationsResponse,
    ListKyuubiTokenRequest,
    ListKyuubiTokenResponseBody,
    ListKyuubiTokenResponse,
    ListLivyComputeRequest,
    ListLivyComputeResponseBody,
    ListLivyComputeResponse,
    ListLivyComputeSessionsRequest,
    ListLivyComputeSessionsResponseBody,
    ListLivyComputeSessionsResponse,
    ListLivyComputeTokenRequest,
    ListLivyComputeTokenResponseBody,
    ListLivyComputeTokenResponse,
    ListLogContentsRequest,
    ListLogContentsResponseBody,
    ListLogContentsResponse,
    ListMembersRequest,
    ListMembersResponseBody,
    ListMembersResponse,
    ListRayClusterRequest,
    ListRayClusterResponseBody,
    ListRayClusterResponse,
    ListReleaseVersionsRequest,
    ListReleaseVersionsResponseBody,
    ListReleaseVersionsResponse,
    ListSessionClustersRequest,
    ListSessionClustersResponseBody,
    ListSessionClustersResponse,
    ListSqlStatementContentsRequest,
    ListSqlStatementContentsResponseBody,
    ListSqlStatementContentsResponse,
    ListTemplateRequest,
    ListTemplateResponseBody,
    ListTemplateResponse,
    ListWorkspaceQueuesRequest,
    ListWorkspaceQueuesResponseBody,
    ListWorkspaceQueuesResponse,
    ListWorkspacesRequest,
    ListWorkspacesShrinkRequest,
    ListWorkspacesResponseBody,
    ListWorkspacesResponse,
    RefreshLivyComputeTokenRequest,
    RefreshLivyComputeTokenResponseBody,
    RefreshLivyComputeTokenResponse,
    StartJobRunRequest,
    StartJobRunResponseBody,
    StartJobRunResponse,
    StartKyuubiServiceResponseBody,
    StartKyuubiServiceResponse,
    StartLivyComputeRequest,
    StartLivyComputeResponseBody,
    StartLivyComputeResponse,
    StartProcessInstanceRequest,
    StartProcessInstanceResponseBody,
    StartProcessInstanceResponse,
    StartRayClusterRequest,
    StartRayClusterResponseBody,
    StartRayClusterResponse,
    StartSessionClusterRequest,
    StartSessionClusterResponseBody,
    StartSessionClusterResponse,
    StopKyuubiServiceResponseBody,
    StopKyuubiServiceResponse,
    StopLivyComputeRequest,
    StopLivyComputeResponseBody,
    StopLivyComputeResponse,
    StopRayClusterRequest,
    StopRayClusterResponseBody,
    StopRayClusterResponse,
    StopSessionClusterRequest,
    StopSessionClusterResponseBody,
    StopSessionClusterResponse,
    TerminateSqlStatementRequest,
    TerminateSqlStatementResponseBody,
    TerminateSqlStatementResponse,
    UpdateKyuubiServiceRequest,
    UpdateKyuubiServiceResponseBody,
    UpdateKyuubiServiceResponse,
    UpdateKyuubiTokenRequest,
    UpdateKyuubiTokenResponseBody,
    UpdateKyuubiTokenResponse,
    UpdateLivyComputeRequest,
    UpdateLivyComputeResponseBody,
    UpdateLivyComputeResponse,
    UpdateProcessDefinitionWithScheduleRequest,
    UpdateProcessDefinitionWithScheduleShrinkRequest,
    UpdateProcessDefinitionWithScheduleResponseBody,
    UpdateProcessDefinitionWithScheduleResponse,
    UpdateRayClusterRequest,
    UpdateRayClusterResponseBody,
    UpdateRayClusterResponse,
    ConfigurationOverridesConfigurations,
    JobDriverSparkSubmit,
    SqlOutputRows,
    SqlOutputSchemaFields,
    SqlOutputSchema,
    TaskCredential,
    CancelKyuubiSparkApplicationResponseBodyBody,
    CreateKyuubiServiceResponseBodyData,
    CreateKyuubiTokenRequestAutoExpireConfiguration,
    CreateKyuubiTokenResponseBodyData,
    CreateLivyComputeRequestAutoStartConfiguration,
    CreateLivyComputeRequestAutoStopConfiguration,
    CreateLivyComputeResponseBodyData,
    CreateLivyComputeTokenRequestAutoExpireConfiguration,
    CreateLivyComputeTokenResponseBodyData,
    CreateProcessDefinitionWithScheduleRequestGlobalParams,
    CreateProcessDefinitionWithScheduleRequestSchedule,
    CreateProcessDefinitionWithScheduleRequestTaskDefinitionJsonTaskParamsLocalParams,
    CreateProcessDefinitionWithScheduleRequestTaskDefinitionJsonTaskParamsSparkConf,
    CreateProcessDefinitionWithScheduleRequestTaskDefinitionJsonTaskParams,
    CreateProcessDefinitionWithScheduleRequestTaskDefinitionJson,
    CreateProcessDefinitionWithScheduleRequestTaskRelationJson,
    CreateProcessDefinitionWithScheduleResponseBodyData,
    CreateRayClusterRequestHeadSpec,
    CreateRayClusterRequestWorkerSpec,
    CreateSessionClusterRequestApplicationConfigs,
    CreateSessionClusterRequestAutoStartConfiguration,
    CreateSessionClusterRequestAutoStopConfiguration,
    CreateSqlStatementResponseBodyData,
    CreateWorkspaceRequestResourceSpec,
    CreateWorkspaceRequestTag,
    EditWorkspaceQueueRequestResourceSpec,
    GetCuHoursResponseBodyData,
    GetDoctorApplicationResponseBodyData,
    GetJobRunResponseBodyJobRunConfigurationOverrides,
    GetJobRunResponseBodyJobRunStateChangeReason,
    GetJobRunResponseBodyJobRun,
    GetKyuubiServiceResponseBodyData,
    GetKyuubiTokenResponseBodyDataAutoExpireConfiguration,
    GetKyuubiTokenResponseBodyData,
    GetLivyComputeResponseBodyDataAutoStopConfiguration,
    GetLivyComputeResponseBodyData,
    GetLivyComputeTokenResponseBodyDataAutoExpireConfiguration,
    GetLivyComputeTokenResponseBodyData,
    GetRayClusterResponseBodyHeadSpec,
    GetRayClusterResponseBodyInstances,
    GetRayClusterResponseBodyWorkerSpec,
    GetRunConfigurationResponseBodyRunConfigurationApplicationConfigs,
    GetRunConfigurationResponseBodyRunConfigurationLogConfig,
    GetRunConfigurationResponseBodyRunConfiguration,
    GetSessionClusterResponseBodySessionClusterApplicationConfigs,
    GetSessionClusterResponseBodySessionClusterAutoStartConfiguration,
    GetSessionClusterResponseBodySessionClusterAutoStopConfiguration,
    GetSessionClusterResponseBodySessionClusterStateChangeReason,
    GetSessionClusterResponseBodySessionCluster,
    GetSqlStatementResponseBodyDataSqlOutputs,
    GetSqlStatementResponseBodyData,
    ListCatalogsResponseBodyCatalogs,
    ListJobExecutorsResponseBodyExexutors,
    ListJobRunsRequestEndTime,
    ListJobRunsRequestStartTime,
    ListJobRunsRequestTags,
    ListJobRunsResponseBodyJobRunsConfigurationOverrides,
    ListJobRunsResponseBodyJobRunsStateChangeReason,
    ListJobRunsResponseBodyJobRuns,
    ListKyuubiServicesResponseBodyDataKyuubiServices,
    ListKyuubiServicesResponseBodyData,
    ListKyuubiSparkApplicationsRequestEndTime,
    ListKyuubiSparkApplicationsRequestStartTime,
    ListKyuubiSparkApplicationsResponseBodyApplications,
    ListKyuubiTokenResponseBodyDataTokens,
    ListKyuubiTokenResponseBodyData,
    ListLivyComputeResponseBodyDataLivyComputes,
    ListLivyComputeResponseBodyData,
    ListLivyComputeSessionsResponseBodySessions,
    ListLivyComputeTokenResponseBodyDataTokens,
    ListLivyComputeTokenResponseBodyData,
    ListLogContentsResponseBodyListLogContentContents,
    ListLogContentsResponseBodyListLogContent,
    ListMembersResponseBodyMembersActions,
    ListMembersResponseBodyMembersRolesActions,
    ListMembersResponseBodyMembersRoles,
    ListMembersResponseBodyMembers,
    ListRayClusterResponseBodyRayClustersHeadSpec,
    ListRayClusterResponseBodyRayClustersWorkerSpec,
    ListRayClusterResponseBodyRayClusters,
    ListReleaseVersionsResponseBodyReleaseVersions,
    ListSessionClustersResponseBodySessionClustersApplicationConfigs,
    ListSessionClustersResponseBodySessionClustersAutoStartConfiguration,
    ListSessionClustersResponseBodySessionClustersAutoStopConfiguration,
    ListSessionClustersResponseBodySessionClustersStateChangeReason,
    ListSessionClustersResponseBodySessionClusters,
    ListSqlStatementContentsResponseBodySqlStatementContents,
    ListWorkspaceQueuesResponseBodyQueuesAllowActions,
    ListWorkspaceQueuesResponseBodyQueues,
    ListWorkspacesRequestTag,
    ListWorkspacesResponseBodyWorkspacesPrePaidQuota,
    ListWorkspacesResponseBodyWorkspacesStateChangeReason,
    ListWorkspacesResponseBodyWorkspacesTags,
    ListWorkspacesResponseBodyWorkspaces,
    RefreshLivyComputeTokenRequestAutoExpireConfiguration,
    StartJobRunRequestConfigurationOverridesConfigurations,
    StartJobRunRequestConfigurationOverrides,
    UpdateKyuubiTokenRequestAutoExpireConfiguration,
    UpdateLivyComputeRequestAutoStartConfiguration,
    UpdateLivyComputeRequestAutoStopConfiguration,
    UpdateProcessDefinitionWithScheduleRequestGlobalParams,
    UpdateProcessDefinitionWithScheduleRequestSchedule,
    UpdateProcessDefinitionWithScheduleRequestTaskDefinitionJsonTaskParamsLocalParams,
    UpdateProcessDefinitionWithScheduleRequestTaskDefinitionJsonTaskParamsSparkConf,
    UpdateProcessDefinitionWithScheduleRequestTaskDefinitionJsonTaskParams,
    UpdateProcessDefinitionWithScheduleRequestTaskDefinitionJson,
    UpdateProcessDefinitionWithScheduleRequestTaskRelationJson,
    UpdateProcessDefinitionWithScheduleResponseBodyData,
    UpdateRayClusterRequestHeadSpec,
    UpdateRayClusterRequestWorkerSpec
]



# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class PrincipalAction(DaraModel):
    def __init__(
        self,
        action_arn: str = None,
        principal_arn: str = None,
    ):
        # The ARN of the behavior.
        self.action_arn = action_arn
        # The ARN of the principal.
        self.principal_arn = principal_arn

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.action_arn is not None:
            result['actionArn'] = self.action_arn

        if self.principal_arn is not None:
            result['principalArn'] = self.principal_arn

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('actionArn') is not None:
            self.action_arn = m.get('actionArn')

        if m.get('principalArn') is not None:
            self.principal_arn = m.get('principalArn')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class ListTemplateResponseBody(DaraModel):
    def __init__(
        self,
        data: List[main_models.Template] = None,
        error_code: str = None,
        error_message: str = None,
        http_status_code: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        self.data = data
        self.error_code = error_code
        self.error_message = error_message
        self.http_status_code = http_status_code
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['data'].append(k1.to_map() if k1 else None)

        if self.error_code is not None:
            result['errorCode'] = self.error_code

        if self.error_message is not None:
            result['errorMessage'] = self.error_message

        if self.http_status_code is not None:
            result['httpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.data = []
        if m.get('data') is not None:
            for k1 in m.get('data'):
                temp_model = main_models.Template()
                self.data.append(temp_model.from_map(k1))

        if m.get('errorCode') is not None:
            self.error_code = m.get('errorCode')

        if m.get('errorMessage') is not None:
            self.error_message = m.get('errorMessage')

        if m.get('httpStatusCode') is not None:
            self.http_status_code = m.get('httpStatusCode')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class CancelKyuubiSparkApplicationResponseBody(DaraModel):
    def __init__(
        self,
        body: main_models.CancelKyuubiSparkApplicationResponseBodyBody = None,
        request_id: str = None,
    ):
        self.body = body
        self.request_id = request_id

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.body is not None:
            result['body'] = self.body.to_map()

        if self.request_id is not None:
            result['requestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('body') is not None:
            temp_model = main_models.CancelKyuubiSparkApplicationResponseBodyBody()
            self.body = temp_model.from_map(m.get('body'))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        return self

class CancelKyuubiSparkApplicationResponseBodyBody(DaraModel):
    def __init__(
        self,
        application_id: str = None,
        success: bool = None,
    ):
        self.application_id = application_id
        self.success = success

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.application_id is not None:
            result['applicationId'] = self.application_id

        if self.success is not None:
            result['success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('applicationId') is not None:
            self.application_id = m.get('applicationId')

        if m.get('success') is not None:
            self.success = m.get('success')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class GrantRoleToUsersRequest(DaraModel):
    def __init__(
        self,
        role_arn: str = None,
        user_arns: List[str] = None,
        region_id: str = None,
    ):
        # The Alibaba Cloud Resource Name (ARN) of the RAM role.
        self.role_arn = role_arn
        # The user ARNs.
        self.user_arns = user_arns
        # The region ID.
        self.region_id = region_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.role_arn is not None:
            result['roleArn'] = self.role_arn

        if self.user_arns is not None:
            result['userArns'] = self.user_arns

        if self.region_id is not None:
            result['regionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('roleArn') is not None:
            self.role_arn = m.get('roleArn')

        if m.get('userArns') is not None:
            self.user_arns = m.get('userArns')

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GenerateTaskCodesRequest(DaraModel):
    def __init__(
        self,
        gen_num: int = None,
        product_namespace: str = None,
        region_id: str = None,
    ):
        # This parameter is required.
        self.gen_num = gen_num
        # This parameter is required.
        self.product_namespace = product_namespace
        self.region_id = region_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.gen_num is not None:
            result['genNum'] = self.gen_num

        if self.product_namespace is not None:
            result['productNamespace'] = self.product_namespace

        if self.region_id is not None:
            result['regionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('genNum') is not None:
            self.gen_num = m.get('genNum')

        if m.get('productNamespace') is not None:
            self.product_namespace = m.get('productNamespace')

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class Artifact(DaraModel):
    def __init__(
        self,
        biz_id: str = None,
        catagory_biz_id: str = None,
        creator: int = None,
        credential: main_models.Credential = None,
        full_path: List[str] = None,
        gmt_created: str = None,
        gmt_modified: str = None,
        location: str = None,
        modifier: int = None,
        modifier_name: str = None,
        name: str = None,
    ):
        # This parameter is required.
        self.biz_id = biz_id
        self.catagory_biz_id = catagory_biz_id
        # This parameter is required.
        self.creator = creator
        self.credential = credential
        self.full_path = full_path
        # This parameter is required.
        self.gmt_created = gmt_created
        # This parameter is required.
        self.gmt_modified = gmt_modified
        # This parameter is required.
        self.location = location
        # This parameter is required.
        self.modifier = modifier
        self.modifier_name = modifier_name
        # This parameter is required.
        self.name = name

    def validate(self):
        if self.credential:
            self.credential.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.biz_id is not None:
            result['bizId'] = self.biz_id

        if self.catagory_biz_id is not None:
            result['catagoryBizId'] = self.catagory_biz_id

        if self.creator is not None:
            result['creator'] = self.creator

        if self.credential is not None:
            result['credential'] = self.credential.to_map()

        if self.full_path is not None:
            result['fullPath'] = self.full_path

        if self.gmt_created is not None:
            result['gmtCreated'] = self.gmt_created

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.location is not None:
            result['location'] = self.location

        if self.modifier is not None:
            result['modifier'] = self.modifier

        if self.modifier_name is not None:
            result['modifierName'] = self.modifier_name

        if self.name is not None:
            result['name'] = self.name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('bizId') is not None:
            self.biz_id = m.get('bizId')

        if m.get('catagoryBizId') is not None:
            self.catagory_biz_id = m.get('catagoryBizId')

        if m.get('creator') is not None:
            self.creator = m.get('creator')

        if m.get('credential') is not None:
            temp_model = main_models.Credential()
            self.credential = temp_model.from_map(m.get('credential'))

        if m.get('fullPath') is not None:
            self.full_path = m.get('fullPath')

        if m.get('gmtCreated') is not None:
            self.gmt_created = m.get('gmtCreated')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('location') is not None:
            self.location = m.get('location')

        if m.get('modifier') is not None:
            self.modifier = m.get('modifier')

        if m.get('modifierName') is not None:
            self.modifier_name = m.get('modifierName')

        if m.get('name') is not None:
            self.name = m.get('name')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListReleaseVersionsRequest(DaraModel):
    def __init__(
        self,
        region_id: str = None,
        release_type: str = None,
        release_version: str = None,
        release_version_status: str = None,
        service_filter: str = None,
        workspace_id: str = None,
    ):
        # The region ID.
        self.region_id = region_id
        # The type of the version.
        # 
        # Valid values:
        # 
        # *   stable
        # *   Beta
        self.release_type = release_type
        # The version of EMR Serverless Spark.
        self.release_version = release_version
        # The status of the version.
        # 
        # Valid values:
        # 
        # *   ONLINE
        # *   OFFLINE
        self.release_version_status = release_version_status
        self.service_filter = service_filter
        # The workspace ID.
        self.workspace_id = workspace_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.region_id is not None:
            result['regionId'] = self.region_id

        if self.release_type is not None:
            result['releaseType'] = self.release_type

        if self.release_version is not None:
            result['releaseVersion'] = self.release_version

        if self.release_version_status is not None:
            result['releaseVersionStatus'] = self.release_version_status

        if self.service_filter is not None:
            result['serviceFilter'] = self.service_filter

        if self.workspace_id is not None:
            result['workspaceId'] = self.workspace_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        if m.get('releaseType') is not None:
            self.release_type = m.get('releaseType')

        if m.get('releaseVersion') is not None:
            self.release_version = m.get('releaseVersion')

        if m.get('releaseVersionStatus') is not None:
            self.release_version_status = m.get('releaseVersionStatus')

        if m.get('serviceFilter') is not None:
            self.service_filter = m.get('serviceFilter')

        if m.get('workspaceId') is not None:
            self.workspace_id = m.get('workspaceId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class Credential(DaraModel):
    def __init__(
        self,
        access_id: str = None,
        dir: str = None,
        expire: str = None,
        host: str = None,
        policy: str = None,
        security_token: str = None,
        signature: str = None,
    ):
        # This parameter is required.
        self.access_id = access_id
        # This parameter is required.
        self.dir = dir
        # This parameter is required.
        self.expire = expire
        # This parameter is required.
        self.host = host
        # This parameter is required.
        self.policy = policy
        # This parameter is required.
        self.security_token = security_token
        # This parameter is required.
        self.signature = signature

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.access_id is not None:
            result['accessId'] = self.access_id

        if self.dir is not None:
            result['dir'] = self.dir

        if self.expire is not None:
            result['expire'] = self.expire

        if self.host is not None:
            result['host'] = self.host

        if self.policy is not None:
            result['policy'] = self.policy

        if self.security_token is not None:
            result['securityToken'] = self.security_token

        if self.signature is not None:
            result['signature'] = self.signature

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('accessId') is not None:
            self.access_id = m.get('accessId')

        if m.get('dir') is not None:
            self.dir = m.get('dir')

        if m.get('expire') is not None:
            self.expire = m.get('expire')

        if m.get('host') is not None:
            self.host = m.get('host')

        if m.get('policy') is not None:
            self.policy = m.get('policy')

        if m.get('securityToken') is not None:
            self.security_token = m.get('securityToken')

        if m.get('signature') is not None:
            self.signature = m.get('signature')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class ListWorkspacesResponseBody(DaraModel):
    def __init__(
        self,
        max_results: int = None,
        next_token: str = None,
        request_id: str = None,
        total_count: int = None,
        workspaces: List[main_models.ListWorkspacesResponseBodyWorkspaces] = None,
    ):
        # The maximum number of entries returned.
        self.max_results = max_results
        # A pagination token. It can be used in the next request to retrieve a new page of results.
        self.next_token = next_token
        # The request ID.
        self.request_id = request_id
        # The total number of entries returned.
        self.total_count = total_count
        # The queried workspaces.
        self.workspaces = workspaces

    def validate(self):
        if self.workspaces:
            for v1 in self.workspaces:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.max_results is not None:
            result['maxResults'] = self.max_results

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.total_count is not None:
            result['totalCount'] = self.total_count

        result['workspaces'] = []
        if self.workspaces is not None:
            for k1 in self.workspaces:
                result['workspaces'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('totalCount') is not None:
            self.total_count = m.get('totalCount')

        self.workspaces = []
        if m.get('workspaces') is not None:
            for k1 in m.get('workspaces'):
                temp_model = main_models.ListWorkspacesResponseBodyWorkspaces()
                self.workspaces.append(temp_model.from_map(k1))

        return self

class ListWorkspacesResponseBodyWorkspaces(DaraModel):
    def __init__(
        self,
        auto_renew: bool = None,
        auto_renew_period: int = None,
        auto_renew_period_unit: str = None,
        create_time: int = None,
        dlf_catalog_id: str = None,
        dlf_type: str = None,
        duration: int = None,
        end_time: int = None,
        fail_reason: str = None,
        gpu_spec: List[str] = None,
        payment_duration_unit: str = None,
        payment_status: str = None,
        payment_type: str = None,
        pre_paid_quota: main_models.ListWorkspacesResponseBodyWorkspacesPrePaidQuota = None,
        region_id: str = None,
        release_type: str = None,
        resource_group_id: str = None,
        resource_spec: str = None,
        state_change_reason: main_models.ListWorkspacesResponseBodyWorkspacesStateChangeReason = None,
        storage: str = None,
        tags: List[main_models.ListWorkspacesResponseBodyWorkspacesTags] = None,
        workspace_id: str = None,
        workspace_name: str = None,
        workspace_status: str = None,
    ):
        # Specifies whether to enable auto-renewal. This parameter is required only if the paymentType parameter is set to Pre.
        self.auto_renew = auto_renew
        # The auto-renewal duration. This parameter is required only if the paymentType parameter is set to Pre.
        self.auto_renew_period = auto_renew_period
        # The unit of the auto-renewal duration. This parameter is required only if the paymentType parameter is set to Pre.
        self.auto_renew_period_unit = auto_renew_period_unit
        # The time when the workflow was created.
        self.create_time = create_time
        # The information of the Data Lake Formation (DLF) catalog.
        self.dlf_catalog_id = dlf_catalog_id
        # The version of DLF.
        self.dlf_type = dlf_type
        # The subscription period. This parameter is required only if the paymentType parameter is set to Pre.
        self.duration = duration
        # The end of the end time range.
        self.end_time = end_time
        # The failure reason.
        self.fail_reason = fail_reason
        self.gpu_spec = gpu_spec
        # The unit of the subscription duration.
        self.payment_duration_unit = payment_duration_unit
        # The status of the payment.
        self.payment_status = payment_status
        # The billing method. Valid values:
        # 
        # - PayAsYouGo
        # - Pre
        self.payment_type = payment_type
        # The information about the subscription quota.
        self.pre_paid_quota = pre_paid_quota
        # The region ID.
        self.region_id = region_id
        # The reason why the workspace is released.
        self.release_type = release_type
        self.resource_group_id = resource_group_id
        # The resource specifications.
        self.resource_spec = resource_spec
        # The reason of the job status change.
        self.state_change_reason = state_change_reason
        # The OSS path.
        self.storage = storage
        self.tags = tags
        # The workspace ID.
        self.workspace_id = workspace_id
        # The name of the workspace.
        self.workspace_name = workspace_name
        # The workspace status.
        self.workspace_status = workspace_status

    def validate(self):
        if self.pre_paid_quota:
            self.pre_paid_quota.validate()
        if self.state_change_reason:
            self.state_change_reason.validate()
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_renew is not None:
            result['autoRenew'] = self.auto_renew

        if self.auto_renew_period is not None:
            result['autoRenewPeriod'] = self.auto_renew_period

        if self.auto_renew_period_unit is not None:
            result['autoRenewPeriodUnit'] = self.auto_renew_period_unit

        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.dlf_catalog_id is not None:
            result['dlfCatalogId'] = self.dlf_catalog_id

        if self.dlf_type is not None:
            result['dlfType'] = self.dlf_type

        if self.duration is not None:
            result['duration'] = self.duration

        if self.end_time is not None:
            result['endTime'] = self.end_time

        if self.fail_reason is not None:
            result['failReason'] = self.fail_reason

        if self.gpu_spec is not None:
            result['gpuSpec'] = self.gpu_spec

        if self.payment_duration_unit is not None:
            result['paymentDurationUnit'] = self.payment_duration_unit

        if self.payment_status is not None:
            result['paymentStatus'] = self.payment_status

        if self.payment_type is not None:
            result['paymentType'] = self.payment_type

        if self.pre_paid_quota is not None:
            result['prePaidQuota'] = self.pre_paid_quota.to_map()

        if self.region_id is not None:
            result['regionId'] = self.region_id

        if self.release_type is not None:
            result['releaseType'] = self.release_type

        if self.resource_group_id is not None:
            result['resourceGroupId'] = self.resource_group_id

        if self.resource_spec is not None:
            result['resourceSpec'] = self.resource_spec

        if self.state_change_reason is not None:
            result['stateChangeReason'] = self.state_change_reason.to_map()

        if self.storage is not None:
            result['storage'] = self.storage

        result['tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['tags'].append(k1.to_map() if k1 else None)

        if self.workspace_id is not None:
            result['workspaceId'] = self.workspace_id

        if self.workspace_name is not None:
            result['workspaceName'] = self.workspace_name

        if self.workspace_status is not None:
            result['workspaceStatus'] = self.workspace_status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('autoRenew') is not None:
            self.auto_renew = m.get('autoRenew')

        if m.get('autoRenewPeriod') is not None:
            self.auto_renew_period = m.get('autoRenewPeriod')

        if m.get('autoRenewPeriodUnit') is not None:
            self.auto_renew_period_unit = m.get('autoRenewPeriodUnit')

        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('dlfCatalogId') is not None:
            self.dlf_catalog_id = m.get('dlfCatalogId')

        if m.get('dlfType') is not None:
            self.dlf_type = m.get('dlfType')

        if m.get('duration') is not None:
            self.duration = m.get('duration')

        if m.get('endTime') is not None:
            self.end_time = m.get('endTime')

        if m.get('failReason') is not None:
            self.fail_reason = m.get('failReason')

        if m.get('gpuSpec') is not None:
            self.gpu_spec = m.get('gpuSpec')

        if m.get('paymentDurationUnit') is not None:
            self.payment_duration_unit = m.get('paymentDurationUnit')

        if m.get('paymentStatus') is not None:
            self.payment_status = m.get('paymentStatus')

        if m.get('paymentType') is not None:
            self.payment_type = m.get('paymentType')

        if m.get('prePaidQuota') is not None:
            temp_model = main_models.ListWorkspacesResponseBodyWorkspacesPrePaidQuota()
            self.pre_paid_quota = temp_model.from_map(m.get('prePaidQuota'))

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        if m.get('releaseType') is not None:
            self.release_type = m.get('releaseType')

        if m.get('resourceGroupId') is not None:
            self.resource_group_id = m.get('resourceGroupId')

        if m.get('resourceSpec') is not None:
            self.resource_spec = m.get('resourceSpec')

        if m.get('stateChangeReason') is not None:
            temp_model = main_models.ListWorkspacesResponseBodyWorkspacesStateChangeReason()
            self.state_change_reason = temp_model.from_map(m.get('stateChangeReason'))

        if m.get('storage') is not None:
            self.storage = m.get('storage')

        self.tags = []
        if m.get('tags') is not None:
            for k1 in m.get('tags'):
                temp_model = main_models.ListWorkspacesResponseBodyWorkspacesTags()
                self.tags.append(temp_model.from_map(k1))

        if m.get('workspaceId') is not None:
            self.workspace_id = m.get('workspaceId')

        if m.get('workspaceName') is not None:
            self.workspace_name = m.get('workspaceName')

        if m.get('workspaceStatus') is not None:
            self.workspace_status = m.get('workspaceStatus')

        return self

class ListWorkspacesResponseBodyWorkspacesTags(DaraModel):
    def __init__(
        self,
        tag_key: str = None,
        tag_value: str = None,
    ):
        self.tag_key = tag_key
        self.tag_value = tag_value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.tag_key is not None:
            result['tagKey'] = self.tag_key

        if self.tag_value is not None:
            result['tagValue'] = self.tag_value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('tagKey') is not None:
            self.tag_key = m.get('tagKey')

        if m.get('tagValue') is not None:
            self.tag_value = m.get('tagValue')

        return self

class ListWorkspacesResponseBodyWorkspacesStateChangeReason(DaraModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
    ):
        # The error code.
        self.code = code
        # The error message.
        self.message = message

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['code'] = self.code

        if self.message is not None:
            result['message'] = self.message

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('code') is not None:
            self.code = m.get('code')

        if m.get('message') is not None:
            self.message = m.get('message')

        return self

class ListWorkspacesResponseBodyWorkspacesPrePaidQuota(DaraModel):
    def __init__(
        self,
        allocated_resource: str = None,
        auto_renewal: bool = None,
        create_time: int = None,
        expire_time: int = None,
        instance_id: str = None,
        max_resource: str = None,
        order_id: str = None,
        payment_status: str = None,
        used_resource: str = None,
    ):
        # The amount of resources that are allocated by a subscription quota.
        self.allocated_resource = allocated_resource
        # Indicates whether auto-renewal is enabled for the subscription quota.
        # 
        # *   true
        # *   false
        self.auto_renewal = auto_renewal
        # The creation time of the subscription quota.
        self.create_time = create_time
        # The expiration time of the subscription quota.
        self.expire_time = expire_time
        # The ID of the instance that is generated when you purchase the subscription quota.
        self.instance_id = instance_id
        # The maximum amount of resources that can be used in a subscription quota.
        self.max_resource = max_resource
        self.order_id = order_id
        # The status of the subscription quota. Valid values:
        # 
        # *   NORMAL
        # *   WAIT_FOR_EXPIRE
        # *   EXPIRED
        self.payment_status = payment_status
        # The amount of resources that are used.
        self.used_resource = used_resource

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.allocated_resource is not None:
            result['allocatedResource'] = self.allocated_resource

        if self.auto_renewal is not None:
            result['autoRenewal'] = self.auto_renewal

        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.expire_time is not None:
            result['expireTime'] = self.expire_time

        if self.instance_id is not None:
            result['instanceId'] = self.instance_id

        if self.max_resource is not None:
            result['maxResource'] = self.max_resource

        if self.order_id is not None:
            result['orderId'] = self.order_id

        if self.payment_status is not None:
            result['paymentStatus'] = self.payment_status

        if self.used_resource is not None:
            result['usedResource'] = self.used_resource

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('allocatedResource') is not None:
            self.allocated_resource = m.get('allocatedResource')

        if m.get('autoRenewal') is not None:
            self.auto_renewal = m.get('autoRenewal')

        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('expireTime') is not None:
            self.expire_time = m.get('expireTime')

        if m.get('instanceId') is not None:
            self.instance_id = m.get('instanceId')

        if m.get('maxResource') is not None:
            self.max_resource = m.get('maxResource')

        if m.get('orderId') is not None:
            self.order_id = m.get('orderId')

        if m.get('paymentStatus') is not None:
            self.payment_status = m.get('paymentStatus')

        if m.get('usedResource') is not None:
            self.used_resource = m.get('usedResource')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class UpdateProcessDefinitionWithScheduleResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: main_models.UpdateProcessDefinitionWithScheduleResponseBodyData = None,
        failed: str = None,
        http_status_code: int = None,
        msg: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The code that is returned by the backend server.
        self.code = code
        # The data returned.
        self.data = data
        # Indicates whether the request failed.
        self.failed = failed
        # The HTTP status code.
        self.http_status_code = http_status_code
        # The description of the returned code.
        self.msg = msg
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful.
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['code'] = self.code

        if self.data is not None:
            result['data'] = self.data.to_map()

        if self.failed is not None:
            result['failed'] = self.failed

        if self.http_status_code is not None:
            result['httpStatusCode'] = self.http_status_code

        if self.msg is not None:
            result['msg'] = self.msg

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('code') is not None:
            self.code = m.get('code')

        if m.get('data') is not None:
            temp_model = main_models.UpdateProcessDefinitionWithScheduleResponseBodyData()
            self.data = temp_model.from_map(m.get('data'))

        if m.get('failed') is not None:
            self.failed = m.get('failed')

        if m.get('httpStatusCode') is not None:
            self.http_status_code = m.get('httpStatusCode')

        if m.get('msg') is not None:
            self.msg = m.get('msg')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        return self

class UpdateProcessDefinitionWithScheduleResponseBodyData(DaraModel):
    def __init__(
        self,
        alert_email_address: str = None,
        biz_id: str = None,
        code: str = None,
        create_time: str = None,
        crontab: str = None,
        description: str = None,
        end_time: str = None,
        execution_type: str = None,
        id: str = None,
        name: str = None,
        project_name: str = None,
        release_state: str = None,
        start_time: str = None,
        timezone_id: str = None,
        update_time: str = None,
        user_id: str = None,
        user_name: str = None,
        version: int = None,
        version_hash_code: str = None,
    ):
        # The email address to receive alerts.
        self.alert_email_address = alert_email_address
        # The workspace ID.
        self.biz_id = biz_id
        # The workflow ID.
        self.code = code
        # The time when the workflow was created.
        self.create_time = create_time
        # The CRON expression that is used for scheduling.
        self.crontab = crontab
        # The node description.
        self.description = description
        # The end of the end time range.
        self.end_time = end_time
        # The execution policy.
        self.execution_type = execution_type
        # The serial number of the workflow.
        self.id = id
        # The name of the workflow.
        self.name = name
        # The name of the project to which the workflow belongs.
        self.project_name = project_name
        # The status of the workflow.
        self.release_state = release_state
        # The start time of the scheduling.
        self.start_time = start_time
        # The ID of the time zone.
        self.timezone_id = timezone_id
        # The time when the workflow was updated.
        self.update_time = update_time
        # The ID of the user that is used to initiate a scheduling.
        self.user_id = user_id
        # The name of the user that is used to initiate a scheduling.
        self.user_name = user_name
        # The version number.
        self.version = version
        # The hash code of the version.
        self.version_hash_code = version_hash_code

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.alert_email_address is not None:
            result['alertEmailAddress'] = self.alert_email_address

        if self.biz_id is not None:
            result['bizId'] = self.biz_id

        if self.code is not None:
            result['code'] = self.code

        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.crontab is not None:
            result['crontab'] = self.crontab

        if self.description is not None:
            result['description'] = self.description

        if self.end_time is not None:
            result['endTime'] = self.end_time

        if self.execution_type is not None:
            result['executionType'] = self.execution_type

        if self.id is not None:
            result['id'] = self.id

        if self.name is not None:
            result['name'] = self.name

        if self.project_name is not None:
            result['projectName'] = self.project_name

        if self.release_state is not None:
            result['releaseState'] = self.release_state

        if self.start_time is not None:
            result['startTime'] = self.start_time

        if self.timezone_id is not None:
            result['timezoneId'] = self.timezone_id

        if self.update_time is not None:
            result['updateTime'] = self.update_time

        if self.user_id is not None:
            result['userId'] = self.user_id

        if self.user_name is not None:
            result['userName'] = self.user_name

        if self.version is not None:
            result['version'] = self.version

        if self.version_hash_code is not None:
            result['versionHashCode'] = self.version_hash_code

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('alertEmailAddress') is not None:
            self.alert_email_address = m.get('alertEmailAddress')

        if m.get('bizId') is not None:
            self.biz_id = m.get('bizId')

        if m.get('code') is not None:
            self.code = m.get('code')

        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('crontab') is not None:
            self.crontab = m.get('crontab')

        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('endTime') is not None:
            self.end_time = m.get('endTime')

        if m.get('executionType') is not None:
            self.execution_type = m.get('executionType')

        if m.get('id') is not None:
            self.id = m.get('id')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('projectName') is not None:
            self.project_name = m.get('projectName')

        if m.get('releaseState') is not None:
            self.release_state = m.get('releaseState')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        if m.get('timezoneId') is not None:
            self.timezone_id = m.get('timezoneId')

        if m.get('updateTime') is not None:
            self.update_time = m.get('updateTime')

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        if m.get('userName') is not None:
            self.user_name = m.get('userName')

        if m.get('version') is not None:
            self.version = m.get('version')

        if m.get('versionHashCode') is not None:
            self.version_hash_code = m.get('versionHashCode')

        return self

